/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (https://www.swig.org).
 * Version 4.4.0
 *
 * Do not make changes to this file unless you know what you are doing - modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

#define SWIG_TYPE_TABLE ufal_morphodita



#define SWIG_VERSION 0x040400
#define SWIGPERL
#define SWIG_CASTRANK_MODE

/* -----------------------------------------------------------------------------
 *  This section contains generic SWIG labels for method/variable
 *  declarations/attributes, and other compiler dependent labels.
 * ----------------------------------------------------------------------------- */

/* template workaround for compilers that cannot correctly implement the C++ standard */
#ifndef SWIGTEMPLATEDISAMBIGUATOR
# if defined(__SUNPRO_CC) && (__SUNPRO_CC <= 0x560)
#  define SWIGTEMPLATEDISAMBIGUATOR template
# elif defined(__HP_aCC)
/* Needed even with `aCC -AA' when `aCC -V' reports HP ANSI C++ B3910B A.03.55 */
/* If we find a maximum version that requires this, the test would be __HP_aCC <= 35500 for A.03.55 */
#  define SWIGTEMPLATEDISAMBIGUATOR template
# else
#  define SWIGTEMPLATEDISAMBIGUATOR
# endif
#endif

/* inline attribute */
#ifndef SWIGINLINE
# if defined(__cplusplus) || (defined(__GNUC__) && !defined(__STRICT_ANSI__))
#   define SWIGINLINE inline
# else
#   define SWIGINLINE
# endif
#endif

/* attribute recognised by some compilers to avoid 'unused' warnings */
#ifndef SWIGUNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define SWIGUNUSED __attribute__ ((__unused__))
#   else
#     define SWIGUNUSED
#   endif
# elif defined(__ICC)
#   define SWIGUNUSED __attribute__ ((__unused__))
# else
#   define SWIGUNUSED
# endif
#endif

#ifndef SWIG_MSC_UNSUPPRESS_4505
# if defined(_MSC_VER)
#   pragma warning(disable : 4505) /* unreferenced local function has been removed */
# endif
#endif

#ifndef SWIGUNUSEDPARM
# ifdef __cplusplus
#   define SWIGUNUSEDPARM(p)
# else
#   define SWIGUNUSEDPARM(p) p SWIGUNUSED
# endif
#endif

/* internal SWIG method */
#ifndef SWIGINTERN
# define SWIGINTERN static SWIGUNUSED
#endif

/* internal inline SWIG method */
#ifndef SWIGINTERNINLINE
# define SWIGINTERNINLINE SWIGINTERN SWIGINLINE
#endif

/* exporting methods */
#if defined(__GNUC__)
#  if (__GNUC__ >= 4) || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4)
#    ifndef GCC_HASCLASSVISIBILITY
#      define GCC_HASCLASSVISIBILITY
#    endif
#  endif
#endif

#ifndef SWIGEXPORT
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   if defined(STATIC_LINKED)
#     define SWIGEXPORT
#   else
#     define SWIGEXPORT __declspec(dllexport)
#   endif
# else
#   if defined(__GNUC__) && defined(GCC_HASCLASSVISIBILITY)
#     define SWIGEXPORT __attribute__ ((visibility("default")))
#   else
#     define SWIGEXPORT
#   endif
# endif
#endif

/* calling conventions for Windows */
#ifndef SWIGSTDCALL
# if defined(_WIN32) || defined(__WIN32__) || defined(__CYGWIN__)
#   define SWIGSTDCALL __stdcall
# else
#   define SWIGSTDCALL
# endif
#endif

/* Deal with Microsoft's attempt at deprecating C standard runtime functions */
#if !defined(SWIG_NO_CRT_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_CRT_SECURE_NO_DEPRECATE)
# define _CRT_SECURE_NO_DEPRECATE
#endif

/* Deal with Microsoft's attempt at deprecating methods in the standard C++ library */
#if !defined(SWIG_NO_SCL_SECURE_NO_DEPRECATE) && defined(_MSC_VER) && !defined(_SCL_SECURE_NO_DEPRECATE)
# define _SCL_SECURE_NO_DEPRECATE
#endif

/* Deal with Apple's deprecated 'AssertMacros.h' from Carbon-framework */
#if defined(__APPLE__) && !defined(__ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES)
# define __ASSERT_MACROS_DEFINE_VERSIONS_WITHOUT_UNDERSCORES 0
#endif

/* Intel's compiler complains if a variable which was never initialised is
 * cast to void, which is a common idiom which we use to indicate that we
 * are aware a variable isn't used.  So we just silence that warning.
 * See: https://github.com/swig/swig/issues/192 for more discussion.
 */
#ifdef __INTEL_COMPILER
# pragma warning disable 592
#endif

#if defined(__cplusplus) && __cplusplus >=201103L
# define SWIG_NOEXCEPT noexcept
#else
# define SWIG_NOEXCEPT throw()
#endif 

/* -----------------------------------------------------------------------------
 * swigcompat.swg
 *
 * Macros to provide support compatibility with older C and C++ standards.
 *
 * Note that SWIG expects __cplusplus to be defined to the appropriate C++ standard.
 * MSVC users are urged to check and examine the /Zc:__cplusplus compiler option.
 * See https://learn.microsoft.com/en-us/cpp/build/reference/zc-cplusplus.
 * ----------------------------------------------------------------------------- */

/* C99 and C++11 should provide snprintf, but define SWIG_NO_SNPRINTF
 * if you're missing it.
 */
#if ((defined __STDC_VERSION__ && __STDC_VERSION__ >= 199901L) || \
     (defined __cplusplus && __cplusplus >= 201103L) || \
     defined SWIG_HAVE_SNPRINTF) && \
    !defined SWIG_NO_SNPRINTF
# define SWIG_snprintf(O,S,F,A) snprintf(O,S,F,A)
# define SWIG_snprintf2(O,S,F,A,B) snprintf(O,S,F,A,B)
#else
/* Fallback versions ignore the buffer size, but most of our uses either have a
 * fixed maximum possible size or dynamically allocate a buffer that's large
 * enough.
 */
# define SWIG_snprintf(O,S,F,A) sprintf(O,F,A)
# define SWIG_snprintf2(O,S,F,A,B) sprintf(O,F,A,B)
#endif

/* -----------------------------------------------------------------------------
 * swigrun.swg
 *
 * This file contains generic C API SWIG runtime support for pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

/* This should only be incremented when either the layout of swig_type_info changes,
   or for whatever reason, the runtime changes incompatibly */
#define SWIG_RUNTIME_VERSION "5"

/* define SWIG_TYPE_TABLE_NAME as "SWIG_TYPE_TABLE" */
#ifdef SWIG_TYPE_TABLE
# define SWIG_QUOTE_STRING(x) #x
# define SWIG_EXPAND_AND_QUOTE_STRING(x) SWIG_QUOTE_STRING(x)
# define SWIG_TYPE_TABLE_NAME SWIG_EXPAND_AND_QUOTE_STRING(SWIG_TYPE_TABLE)
#else
# define SWIG_TYPE_TABLE_NAME
#endif

/*
  You can use the SWIGRUNTIME and SWIGRUNTIMEINLINE macros for
  creating a static or dynamic library from the SWIG runtime code.
  In 99.9% of the cases, SWIG just needs to declare them as 'static'.

  But only do this if strictly necessary, ie, if you have problems
  with your compiler or suchlike.
*/

#ifndef SWIGRUNTIME
# define SWIGRUNTIME SWIGINTERN
#endif

#ifndef SWIGRUNTIMEINLINE
# define SWIGRUNTIMEINLINE SWIGRUNTIME SWIGINLINE
#endif

/*  Generic buffer size */
#ifndef SWIG_BUFFER_SIZE
# define SWIG_BUFFER_SIZE 1024
#endif

/* Flags for pointer conversions */
#define SWIG_POINTER_DISOWN        0x1
#define SWIG_CAST_NEW_MEMORY       0x2
#define SWIG_POINTER_NO_NULL       0x4
#define SWIG_POINTER_CLEAR         0x8
#define SWIG_POINTER_RELEASE       (SWIG_POINTER_CLEAR | SWIG_POINTER_DISOWN)

/* Flags for new pointer objects */
#define SWIG_POINTER_OWN           0x1


/*
   Flags/methods for returning states.

   The SWIG conversion methods, as ConvertPtr, return an integer
   that tells if the conversion was successful or not. And if not,
   an error code can be returned (see swigerrors.swg for the codes).

   Use the following macros/flags to set or process the returning
   states.

   In old versions of SWIG, code such as the following was usually written:

     if (SWIG_ConvertPtr(obj,vptr,ty.flags) != -1) {
       // success code
     } else {
       //fail code
     }

   Now you can be more explicit:

    int res = SWIG_ConvertPtr(obj,vptr,ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
    } else {
      // fail code
    }

   which is the same really, but now you can also do

    Type *ptr;
    int res = SWIG_ConvertPtr(obj,(void **)(&ptr),ty.flags);
    if (SWIG_IsOK(res)) {
      // success code
      if (SWIG_IsNewObj(res) {
        ...
	delete *ptr;
      } else {
        ...
      }
    } else {
      // fail code
    }

   I.e., now SWIG_ConvertPtr can return new objects and you can
   identify the case and take care of the deallocation. Of course that
   also requires SWIG_ConvertPtr to return new result values, such as

      int SWIG_ConvertPtr(obj, ptr,...) {
        if (<obj is ok>) {
          if (<need new object>) {
            *ptr = <ptr to new allocated object>;
            return SWIG_NEWOBJ;
          } else {
            *ptr = <ptr to old object>;
            return SWIG_OLDOBJ;
          }
        } else {
          return SWIG_BADOBJ;
        }
      }

   Of course, returning the plain '0(success)/-1(fail)' still works, but you can be
   more explicit by returning SWIG_BADOBJ, SWIG_ERROR or any of the
   SWIG errors code.

   Finally, if the SWIG_CASTRANK_MODE is enabled, the result code
   allows returning the 'cast rank', for example, if you have this

       int food(double)
       int fooi(int);

   and you call

      food(1)   // cast rank '1'  (1 -> 1.0)
      fooi(1)   // cast rank '0'

   just use the SWIG_AddCast()/SWIG_CheckState()
*/

#define SWIG_OK                    (0)
/* Runtime errors are < 0 */
#define SWIG_ERROR                 (-1)
/* Errors in range -1 to -99 are in swigerrors.swg (errors for all languages including those not using the runtime) */
/* Errors in range -100 to -199 are language specific errors defined in *errors.swg */
/* Errors < -200 are generic runtime specific errors */
#define SWIG_ERROR_RELEASE_NOT_OWNED (-200)

#define SWIG_IsOK(r)               (r >= 0)
#define SWIG_ArgError(r)           ((r != SWIG_ERROR) ? r : SWIG_TypeError)

/* The CastRankLimit says how many bits are used for the cast rank */
#define SWIG_CASTRANKLIMIT         (1 << 8)
/* The NewMask denotes the object was created (using new/malloc) */
#define SWIG_NEWOBJMASK            (SWIG_CASTRANKLIMIT  << 1)
/* The TmpMask is for in/out typemaps that use temporary objects */
#define SWIG_TMPOBJMASK            (SWIG_NEWOBJMASK << 1)
/* Simple returning values */
#define SWIG_BADOBJ                (SWIG_ERROR)
#define SWIG_OLDOBJ                (SWIG_OK)
#define SWIG_NEWOBJ                (SWIG_OK | SWIG_NEWOBJMASK)
#define SWIG_TMPOBJ                (SWIG_OK | SWIG_TMPOBJMASK)
/* Check, add and del object mask methods */
#define SWIG_AddNewMask(r)         (SWIG_IsOK(r) ? (r | SWIG_NEWOBJMASK) : r)
#define SWIG_DelNewMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_NEWOBJMASK) : r)
#define SWIG_IsNewObj(r)           (SWIG_IsOK(r) && (r & SWIG_NEWOBJMASK))
#define SWIG_AddTmpMask(r)         (SWIG_IsOK(r) ? (r | SWIG_TMPOBJMASK) : r)
#define SWIG_DelTmpMask(r)         (SWIG_IsOK(r) ? (r & ~SWIG_TMPOBJMASK) : r)
#define SWIG_IsTmpObj(r)           (SWIG_IsOK(r) && (r & SWIG_TMPOBJMASK))

/* Cast-Rank Mode */
#if defined(SWIG_CASTRANK_MODE)
#  ifndef SWIG_TypeRank
#    define SWIG_TypeRank             unsigned long
#  endif
#  ifndef SWIG_MAXCASTRANK            /* Default cast allowed */
#    define SWIG_MAXCASTRANK          (2)
#  endif
#  define SWIG_CASTRANKMASK          ((SWIG_CASTRANKLIMIT) -1)
#  define SWIG_CastRank(r)           (r & SWIG_CASTRANKMASK)
SWIGINTERNINLINE int SWIG_AddCast(int r) {
  return SWIG_IsOK(r) ? ((SWIG_CastRank(r) < SWIG_MAXCASTRANK) ? (r + 1) : SWIG_ERROR) : r;
}
SWIGINTERNINLINE int SWIG_CheckState(int r) {
  return SWIG_IsOK(r) ? SWIG_CastRank(r) + 1 : 0;
}
#else /* no cast-rank mode */
#  define SWIG_AddCast(r) (r)
#  define SWIG_CheckState(r) (SWIG_IsOK(r) ? 1 : 0)
#endif


#include <string.h>

#ifdef __cplusplus
extern "C" {
#endif

typedef void *(*swig_converter_func)(void *, int *);
typedef struct swig_type_info *(*swig_dycast_func)(void **);

/* Structure to store information on one type */
typedef struct swig_type_info {
  const char             *name;			/* mangled name of this type */
  const char             *str;			/* human readable name of this type */
  swig_dycast_func        dcast;		/* dynamic cast function down a hierarchy */
  struct swig_cast_info  *cast;			/* linked list of types that can cast into this type */
  void                   *clientdata;		/* language specific type data */
  int                    owndata;		/* flag if the structure owns the clientdata */
} swig_type_info;

/* Structure to store a type and conversion function used for casting */
typedef struct swig_cast_info {
  swig_type_info         *type;			/* pointer to type that is equivalent to this type */
  swig_converter_func     converter;		/* function to cast the void pointers */
  struct swig_cast_info  *next;			/* pointer to next array of casts | pointer to cast hashed by value */
  unsigned int            value;		/* index of the last valid element in the array | typename hash value */
} swig_cast_info;

/* Structure used to store module information
 * Each module generates one structure like this, and the runtime collects
 * all of these structures and stores them in a circularly linked list.*/
typedef struct swig_module_info {
  swig_type_info         **types;		/* Array of pointers to swig_type_info structures that are in this module */
  size_t                 size;		        /* Number of types in this module */
  struct swig_module_info *next;		/* Pointer to next element in circularly linked list */
  swig_type_info         **type_initial;	/* Array of initially generated type structures */
  swig_cast_info         **cast_initial;	/* Array of initially generated casting structures */
  void                    *clientdata;		/* Language specific module data */
} swig_module_info;

/*
  Compare two type names skipping the space characters, therefore
  "char*" == "char *" and "Class<int>" == "Class<int >", etc.

  Return 0 when the two name types are equivalent, as in
  strncmp, but skipping ' '.
*/
SWIGRUNTIME int
SWIG_TypeNameComp(const char *f1, const char *l1,
		  const char *f2, const char *l2) {
  for (;(f1 != l1) && (f2 != l2); ++f1, ++f2) {
    while ((*f1 == ' ') && (f1 != l1)) ++f1;
    while ((*f2 == ' ') && (f2 != l2)) ++f2;
    if (*f1 != *f2) return (*f1 > *f2) ? 1 : -1;
  }
  return (int)((l1 - f1) - (l2 - f2));
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if equal, -1 if nb < tb, 1 if nb > tb
*/
SWIGRUNTIME int
SWIG_TypeCmp(const char *nb, const char *tb) {
  int equiv = 1;
  const char* te = tb + strlen(tb);
  const char* ne = nb;
  while (equiv != 0 && *ne) {
    for (nb = ne; *ne; ++ne) {
      if (*ne == '|') break;
    }
    equiv = SWIG_TypeNameComp(nb, ne, tb, te);
    if (*ne) ++ne;
  }
  return equiv;
}

/*
  Check type equivalence in a name list like <name1>|<name2>|...
  Return 0 if not equal, 1 if equal
*/
SWIGRUNTIME int
SWIG_TypeEquiv(const char *nb, const char *tb) {
  return SWIG_TypeCmp(nb, tb) == 0 ? 1 : 0;
}

/*
 * Hash function for type name strings, based on maRushPrime1Hash (http://amsoftware.narod.ru/algo2.html)
 */
SWIGRUNTIME unsigned int SWIG_Hash(const char *str, unsigned int len) {
  const unsigned char *data = (const unsigned char *)str;
  unsigned int hash = len, i = 0, k;
  int rem = (int)len;

  while (rem >= (int)sizeof(unsigned int)) {
    k = *(unsigned int *)data;
    k += i++;
    hash ^= k;
    hash *= 171717;
    data += sizeof(unsigned int);
    rem -= sizeof(unsigned int);
  }

  switch (rem) {
    case 3: k = (unsigned int)(data[2]) << 16;
            k |= (unsigned int)(data[1]) << 8;
            k |= (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
    case 2: k = (unsigned int)(data[1]) << 8;
            k |= (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
    case 1: k = (unsigned int)(data[0]);
            k += i++;
            hash ^= k;
            hash *= 171717;
            break;
  }
  return hash;
}

/*
  Check the typename
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheck(const char *c, swig_type_info *ty) {
  static const unsigned int scan_threshold = 4;
  if (ty) {
    swig_cast_info *head = ty->cast;
    unsigned int hash_value = 0;
    int hashed = 0;

    while (head) {

      if (strcmp(head->type->name, c) == 0) {
        return head;
      }

      if (head->value) {
        swig_cast_info *iter;
        swig_cast_info *last = head + head->value;
        swig_cast_info *first = head + 1;
        int search = 1;

        if (!hashed) {
          if (head->value < scan_threshold) {
            for (iter = first; iter <= last; iter++) {
              if (strcmp(iter->type->name, c) == 0) {
                return iter;
              }
            }
            search = 0;
          } else {
            hashed = 1;
            hash_value = SWIG_Hash(c, (unsigned int)strlen(c));
          }
        }

        if (search) {
          /* Binary search over sorted <'next'|'value'> pairs */
          do {
            iter = first + ((last - first) >> 1);
            if (iter->value < hash_value) {
              first = iter + 1;
            } else if (iter->value == hash_value) {

              if (strcmp(iter->next->type->name, c) == 0) {
                return iter->next;
              }

              /* Hash collision check */
              for (last = iter + 1; last->next && last->value == hash_value; last++) {
                if (strcmp(last->next->type->name, c) == 0) {
                  return last->next;
                }
              }
              for (first = iter - 1; first != head && first->value == hash_value; first--) {
                if (strcmp(first->next->type->name, c) == 0) {
                  return first->next;
                }
              }
              break;
            } else
              last = iter - 1;
          } while (first <= last);
        }
      }
      head = head->next;
    }
  }
  return 0;
}

/*
  Check the type by type address
*/
SWIGRUNTIME swig_cast_info *
SWIG_TypeCheckStruct(const swig_type_info *from, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *head = ty->cast;
    while (head) {
      if (head->type == from) {
        return head;
      }

      if (head->value) {
        swig_cast_info *iter;
        swig_cast_info *last = head + head->value;
        swig_cast_info *first = head + 1;

        /* Binary search over sorted array of casts */
        do {
          iter = first + ((last - first) >> 1);
          if (iter->type < from) {
            first = iter + 1;
          } else if (iter->type == from) {
            return iter;
          } else
            last = iter - 1;
        } while (first <= last);
      }
      head = head->next;
    }
  }
  return 0;
}

/*
  Cast a pointer up an inheritance hierarchy
*/
SWIGRUNTIMEINLINE void *
SWIG_TypeCast(swig_cast_info *ty, void *ptr, int *newmemory) {
  return ((!ty) || (!ty->converter)) ? ptr : (*ty->converter)(ptr, newmemory);
}

/*
   Dynamic pointer casting. Down an inheritance hierarchy
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeDynamicCast(swig_type_info *ty, void **ptr) {
  swig_type_info *lastty = ty;
  if (!ty || !ty->dcast) return ty;
  while (ty && (ty->dcast)) {
    ty = (*ty->dcast)(ptr);
    if (ty) lastty = ty;
  }
  return lastty;
}

/*
  Return the name associated with this type
*/
SWIGRUNTIMEINLINE const char *
SWIG_TypeName(const swig_type_info *ty) {
  return ty->name;
}

/*
  Return the pretty name associated with this type,
  that is an unmangled type name in a form presentable to the user.
*/
SWIGRUNTIME const char *
SWIG_TypePrettyName(const swig_type_info *type) {
  /* The "str" field contains the equivalent pretty names of the
     type, separated by vertical-bar characters.  Choose the last
     name. It should be the most specific; a fully resolved name
     but not necessarily with default template parameters expanded. */
  if (!type) return NULL;
  if (type->str != NULL) {
    const char *last_name = type->str;
    const char *s;
    for (s = type->str; *s; s++)
      if (*s == '|') last_name = s+1;
    return last_name;
  }
  else
    return type->name;
}

/*
   Set the clientdata field for a type
*/
SWIGRUNTIME void
SWIG_TypeClientData(swig_type_info *ti, void *clientdata) {
  swig_cast_info *head = ti->cast;
  /* if (ti->clientdata == clientdata) return; */
  ti->clientdata = clientdata;

  while (head) {
    swig_cast_info *cast;
    for (cast = head; (cast - head) <= head->value; cast++) {
      if (!cast->converter) {
        swig_type_info *tc = cast->type;
        if (!tc->clientdata) {
          SWIG_TypeClientData(tc, clientdata);
        }
      }
    }
    head = head->next;
  }
}

SWIGRUNTIME void
SWIG_TypeNewClientData(swig_type_info *ti, void *clientdata) {
  SWIG_TypeClientData(ti, clientdata);
  ti->owndata = 1;
}

/*
  Search for a swig_type_info structure only by mangled name
  Search is a O(log #types)

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_MangledTypeQueryModule(swig_module_info *start,
                            swig_module_info *end,
		            const char *name) {
  swig_module_info *iter = start;
  do {
    if (iter->size) {
      size_t l = 0;
      size_t r = iter->size - 1;
      do {
	/* since l+r >= 0, we can (>> 1) instead (/ 2) */
	size_t i = (l + r) >> 1;
	const char *iname = iter->types[i]->name;
	if (iname) {
	  int compare = strcmp(name, iname);
	  if (compare == 0) {
	    return iter->types[i];
	  } else if (compare < 0) {
	    if (i) {
	      r = i - 1;
	    } else {
	      break;
	    }
	  } else if (compare > 0) {
	    l = i + 1;
	  }
	} else {
	  break; /* should never happen */
	}
      } while (l <= r);
    }
    iter = iter->next;
  } while (iter != end);
  return 0;
}

/*
  Search for a swig_type_info structure for either a mangled name or a human readable name.
  It first searches the mangled names of the types, which is a O(log #types)
  If a type is not found it then searches the human readable names, which is O(#types).

  We start searching at module start, and finish searching when start == end.
  Note: if start == end at the beginning of the function, we go all the way around
  the circular list.
*/
SWIGRUNTIME swig_type_info *
SWIG_TypeQueryModule(swig_module_info *start,
                     swig_module_info *end,
		     const char *name) {
  /* STEP 1: Search the name field using binary search */
  swig_type_info *ret = SWIG_MangledTypeQueryModule(start, end, name);
  if (ret) {
    return ret;
  } else {
    /* STEP 2: If the type hasn't been found, do a complete search
       of the str field (the human readable name) */
    swig_module_info *iter = start;
    do {
      size_t i = 0;
      for (; i < iter->size; ++i) {
	if (iter->types[i]->str && (SWIG_TypeEquiv(iter->types[i]->str, name)))
	  return iter->types[i];
      }
      iter = iter->next;
    } while (iter != end);
  }

  /* neither found a match */
  return 0;
}

/*
   Pack binary data into a string
*/
SWIGRUNTIME char *
SWIG_PackData(char *c, void *ptr, size_t sz) {
  static const char hex[17] = "0123456789abcdef";
  const unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu =  u + sz;
  for (; u != eu; ++u) {
    unsigned char uu = *u;
    *(c++) = hex[(uu & 0xf0) >> 4];
    *(c++) = hex[uu & 0xf];
  }
  return c;
}

/*
   Unpack binary data from a string
*/
SWIGRUNTIME const char *
SWIG_UnpackData(const char *c, void *ptr, size_t sz) {
  unsigned char *u = (unsigned char *) ptr;
  const unsigned char *eu = u + sz;
  for (; u != eu; ++u) {
    char d = *(c++);
    unsigned char uu;
    if ((d >= '0') && (d <= '9'))
      uu = (unsigned char)((d - '0') << 4);
    else if ((d >= 'a') && (d <= 'f'))
      uu = (unsigned char)((d - ('a'-10)) << 4);
    else
      return (char *) 0;
    d = *(c++);
    if ((d >= '0') && (d <= '9'))
      uu |= (unsigned char)(d - '0');
    else if ((d >= 'a') && (d <= 'f'))
      uu |= (unsigned char)(d - ('a'-10));
    else
      return (char *) 0;
    *u = uu;
  }
  return c;
}

/*
   Pack 'void *' into a string buffer.
*/
SWIGRUNTIME char *
SWIG_PackVoidPtr(char *buff, void *ptr, const char *name, size_t bsz) {
  char *r = buff;
  if ((2*sizeof(void *) + 2) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,&ptr,sizeof(void *));
  if (strlen(name) + 1 > (bsz - (r - buff))) return 0;
  strcpy(r,name);
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackVoidPtr(const char *c, void **ptr, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      *ptr = (void *) 0;
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sizeof(void *));
}

SWIGRUNTIME char *
SWIG_PackDataName(char *buff, void *ptr, size_t sz, const char *name, size_t bsz) {
  char *r = buff;
  size_t lname = (name ? strlen(name) : 0);
  if ((2*sz + 2 + lname) > bsz) return 0;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  if (lname) {
    strncpy(r,name,lname+1);
  } else {
    *r = 0;
  }
  return buff;
}

SWIGRUNTIME const char *
SWIG_UnpackDataName(const char *c, void *ptr, size_t sz, const char *name) {
  if (*c != '_') {
    if (strcmp(c,"NULL") == 0) {
      memset(ptr,0,sz);
      return name;
    } else {
      return 0;
    }
  }
  return SWIG_UnpackData(++c,ptr,sz);
}

#ifdef __cplusplus
}
#endif

/* SWIG Errors applicable to all language modules, values are reserved from -1 to -99 */
#define  SWIG_UnknownError    	   -1
#define  SWIG_IOError        	   -2
#define  SWIG_RuntimeError   	   -3
#define  SWIG_IndexError     	   -4
#define  SWIG_TypeError      	   -5
#define  SWIG_DivisionByZero 	   -6
#define  SWIG_OverflowError  	   -7
#define  SWIG_SyntaxError    	   -8
#define  SWIG_ValueError     	   -9
#define  SWIG_SystemError    	   -10
#define  SWIG_AttributeError 	   -11
#define  SWIG_MemoryError    	   -12
#define  SWIG_NullReferenceError   -13


#ifdef __cplusplus
/* Needed on some windows machines---since MS plays funny games with the header files under C++ */
#include <math.h>
#include <stdlib.h>
extern "C" {
#endif

#if __GNUC__ >= 10
#if defined(__cplusplus)
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wvolatile"
#endif
#endif

#include "EXTERN.h"
#include "perl.h"
#include "XSUB.h"

#if __GNUC__ >= 10
#if defined(__cplusplus)
#pragma GCC diagnostic pop
#endif
#endif

/* PERL_REVISION was added in Perl 5.6. */
#if !defined PERL_REVISION || (PERL_REVISION-0 == 5 && PERL_VERSION-0 < 8)
# error SWIG requires Perl >= 5.8.0
#endif

#if defined(WIN32) && defined(PERL_OBJECT) && !defined(PerlIO_exportFILE)
#define PerlIO_exportFILE(fh,fl) (FILE*)(fh)
#endif

#ifndef SvIOK_UV
# define SvIOK_UV(sv)       (SvIOK(sv) && (SvUVX(sv) == SvIVX(sv)))
#endif

#ifndef SvUOK
# define SvUOK(sv)           SvIOK_UV(sv)
#endif

#ifndef IVSIZE
#  ifdef LONGSIZE
#    define IVSIZE LONGSIZE
#  else
#    define IVSIZE 4 /* A bold guess, but the best we can make. */
#  endif
#endif

#ifndef INT2PTR
#  if (IVSIZE == PTRSIZE) && (UVSIZE == PTRSIZE)
#    define PTRV                  UV
#    define INT2PTR(any,d)        (any)(d)
#  else
#    if PTRSIZE == LONGSIZE
#      define PTRV                unsigned long
#    else
#      define PTRV                unsigned
#    endif
#    define INT2PTR(any,d)        (any)(PTRV)(d)
#  endif

#  define NUM2PTR(any,d)  (any)(PTRV)(d)
#  define PTR2IV(p)       INT2PTR(IV,p)
#  define PTR2UV(p)       INT2PTR(UV,p)
#  define PTR2NV(p)       NUM2PTR(NV,p)

#  if PTRSIZE == LONGSIZE
#    define PTR2ul(p)     (unsigned long)(p)
#  else
#    define PTR2ul(p)     INT2PTR(unsigned long,p)
#  endif
#endif /* !INT2PTR */

#ifndef SvPV_nolen
# define SvPV_nolen(x) SvPV(x,PL_na)
#endif

#ifndef get_sv
#  define get_sv perl_get_sv
#endif

#ifndef ERRSV
#  define ERRSV get_sv("@",FALSE)
#endif

#ifndef pTHX_
#define pTHX_
#endif   

#include <string.h>
#ifdef __cplusplus
}
#endif

/* -----------------------------------------------------------------------------
 * error manipulation
 * ----------------------------------------------------------------------------- */

SWIGINTERN const char*
SWIG_Perl_ErrorType(int code) {
  switch(code) {
  case SWIG_MemoryError:
    return "MemoryError";
  case SWIG_IOError:
    return "IOError";
  case SWIG_RuntimeError:
    return "RuntimeError";
  case SWIG_IndexError:
    return "IndexError";
  case SWIG_TypeError:
    return "TypeError";
  case SWIG_DivisionByZero:
    return "ZeroDivisionError";
  case SWIG_OverflowError:
    return "OverflowError";
  case SWIG_SyntaxError:
    return "SyntaxError";
  case SWIG_ValueError:
    return "ValueError";
  case SWIG_SystemError:
    return "SystemError";
  case SWIG_AttributeError:
    return "AttributeError";
  case SWIG_NullReferenceError:
    return "NullReferenceError";
  default:
    return "RuntimeError";
  }
}


/* -----------------------------------------------------------------------------
 * perlrun.swg
 *
 * This file contains the runtime support for Perl modules
 * and includes code for managing global variables and pointer
 * type checking.
 * ----------------------------------------------------------------------------- */

#define SWIG_PERL_OBJECT_DECL
#define SWIG_PERL_OBJECT_CALL

/* Common SWIG API */

/* for raw pointers */
#define SWIG_ConvertPtr(obj, pp, type, flags)           SWIG_Perl_ConvertPtr(SWIG_PERL_OBJECT_CALL obj, pp, type, flags)
#define SWIG_ConvertPtrAndOwn(obj, pp, type, flags,own) SWIG_Perl_ConvertPtrAndOwn(SWIG_PERL_OBJECT_CALL obj, pp, type, flags, own)
#define SWIG_NewPointerObj(p, type, flags)              SWIG_Perl_NewPointerObj(SWIG_PERL_OBJECT_CALL p, type, flags)
#define SWIG_AcquirePtr(ptr, src)                       SWIG_Perl_AcquirePtr(ptr, src)
#define swig_owntype                                    int

/* for raw packed data */
#define SWIG_ConvertPacked(obj, p, s, type)             SWIG_Perl_ConvertPacked(SWIG_PERL_OBJECT_CALL obj, p, s, type)
#define SWIG_NewPackedObj(p, s, type)	                SWIG_Perl_NewPackedObj(SWIG_PERL_OBJECT_CALL p, s, type)

/* for class or struct pointers */
#define SWIG_ConvertInstance(obj, pptr, type, flags)    SWIG_ConvertPtr(obj, pptr, type, flags)
#define SWIG_NewInstanceObj(ptr, type, flags)           SWIG_NewPointerObj(ptr, type, flags)

/* for C or C++ function pointers */
#define SWIG_ConvertFunctionPtr(obj, pptr, type)        SWIG_ConvertPtr(obj, pptr, type, 0)
#define SWIG_NewFunctionPtrObj(ptr, type)               SWIG_NewPointerObj(ptr, type, 0)

/* for C++ member pointers, ie, member methods */
#define SWIG_ConvertMember(obj, ptr, sz, ty)            SWIG_ConvertPacked(obj, ptr, sz, ty)
#define SWIG_NewMemberObj(ptr, sz, type)                SWIG_NewPackedObj(ptr, sz, type)


/* Runtime API */

#define SWIG_GetModule(clientdata)                      SWIG_Perl_GetModule(clientdata)
#define SWIG_SetModule(clientdata, pointer)             SWIG_Perl_SetModule(pointer)


/* Error manipulation */

#define SWIG_ErrorType(code)                            SWIG_Perl_ErrorType(code)               
#define SWIG_Error(code, msg)            		sv_setpvf(get_sv("@", GV_ADD), "%s %s", SWIG_ErrorType(code), msg)
#define SWIG_fail                        		goto fail						    

/* Perl-specific SWIG API */

#define SWIG_MakePtr(sv, ptr, type, flags)              SWIG_Perl_MakePtr(SWIG_PERL_OBJECT_CALL sv, ptr, type, flags)
#define SWIG_MakePackedObj(sv, p, s, type)	        SWIG_Perl_MakePackedObj(SWIG_PERL_OBJECT_CALL sv, p, s, type)
#define SWIG_SetError(str)                              SWIG_Error(SWIG_RuntimeError, str)


#define SWIG_PERL_DECL_ARGS_1(arg1)                     (SWIG_PERL_OBJECT_DECL arg1)
#define SWIG_PERL_CALL_ARGS_1(arg1)                     (SWIG_PERL_OBJECT_CALL arg1)
#define SWIG_PERL_DECL_ARGS_2(arg1, arg2)               (SWIG_PERL_OBJECT_DECL arg1, arg2)
#define SWIG_PERL_CALL_ARGS_2(arg1, arg2)               (SWIG_PERL_OBJECT_CALL arg1, arg2)

/* -----------------------------------------------------------------------------
 * pointers/data manipulation
 * ----------------------------------------------------------------------------- */

/* For backward compatibility only */
#define SWIG_POINTER_EXCEPTION  0

#ifdef __cplusplus
extern "C" {
#endif

#define SWIG_OWNER   SWIG_POINTER_OWN
#define SWIG_SHADOW  SWIG_OWNER << 1

#define SWIG_MAYBE_PERL_OBJECT SWIG_PERL_OBJECT_DECL

/* SWIG Perl macros */

/* Macro to declare an XS function */
#ifndef XSPROTO
#   define XSPROTO(name) void name(pTHX_ CV* cv)
#endif

/* Macro to call an XS function */
#ifndef MULTIPLICITY
#  define SWIG_CALLXS(_name) _name(cv)
#else
#  define SWIG_CALLXS(_name) _name(PERL_GET_THX, cv)
#endif

#define MAGIC_PPERL
#define SWIGCLASS_STATIC static SWIGUNUSED

#ifndef MULTIPLICITY
#define SWIG_MAGIC(a,b) (SV *a, MAGIC *b)

#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFunc)(SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#else /* MULTIPLICITY */

#define SWIG_MAGIC(a,b) (struct interpreter *interp, SV *a, MAGIC *b)

#ifdef __cplusplus
extern "C" {
#endif
typedef int (*SwigMagicFunc)(struct interpreter *, SV *, MAGIC *);
#ifdef __cplusplus
}
#endif

#endif /* MULTIPLICITY */

static void SWIGUNUSED SWIG_croak_null(void)
{
  SV *err = get_sv("@", GV_ADD);
  if (sv_isobject(err))
    croak(0);
  else
    croak("%s", SvPV_nolen(err));
}


/* 
   Define how strict is the cast between strings and integers/doubles
   when overloading between these types occurs.
   
   The default is making it as strict as possible by using SWIG_AddCast
   when needed.
   
   You can use -DSWIG_PERL_NO_STRICT_STR2NUM at compilation time to
   disable the SWIG_AddCast, making the casting between string and
   numbers less strict.

   In the end, we try to solve the overloading between strings and
   numerical types in the more natural way, but if you can avoid it,
   well, avoid it using %rename, for example.
*/
#ifndef SWIG_PERL_NO_STRICT_STR2NUM
# ifndef SWIG_PERL_STRICT_STR2NUM
#  define SWIG_PERL_STRICT_STR2NUM
# endif
#endif
#ifdef SWIG_PERL_STRICT_STR2NUM
/* string takes precedence */
#define SWIG_Str2NumCast(x) SWIG_AddCast(x)  
#else
/* number takes precedence */
#define SWIG_Str2NumCast(x) x
#endif



#include <stdlib.h>

SWIGRUNTIME const char *
SWIG_Perl_TypeProxyName(const swig_type_info *type) {
  if (type) {
    if (type->clientdata != NULL) {
      return (const char *) type->clientdata;
    }
    else {
      return type->name;
    }
  }
  return NULL;
}

/* SWIG_TypeCheck without binary search by hash value */
SWIGRUNTIME swig_cast_info *
SWIG_TypeProxyCheck(const char *c, swig_type_info *ty) {
  if (ty) {
    swig_cast_info *head, *cast;
    head = ty->cast;
    while (head) {
      for (cast = head; (cast - head) <= head->value; cast++) {
        if (strcmp(SWIG_Perl_TypeProxyName(cast->type), c) == 0) {
          return cast;
        }
      }
      head = head->next;
    }
  }
  return 0;
}

/* Acquire a pointer value */

SWIGRUNTIME int
SWIG_Perl_AcquirePtr(SWIG_MAYBE_PERL_OBJECT SV *SWIGUNUSEDPARM(sv), int SWIGUNUSEDPARM(own)) {
  /* TODO */
  return 0;
}

/* Function for getting a pointer value */

SWIGRUNTIME int
SWIG_Perl_ConvertPtrAndOwn(SWIG_MAYBE_PERL_OBJECT SV *sv, void **ptr, swig_type_info *_t, int flags, int *own) {
  swig_cast_info *tc;
  void *voidptr = (void *)0;
  SV *tsv = 0;
  int check_owned_pointer_release = (flags & SWIG_POINTER_RELEASE) == SWIG_POINTER_RELEASE;

  if (own)
    *own = 0;

  /* If magical, apply more magic */
  if (SvGMAGICAL(sv))
    mg_get(sv);

  /* Check to see if this is an object */
  if (sv_isobject(sv)) {
    IV tmp = 0;
    tsv = (SV*) SvRV(sv);
    if ((SvTYPE(tsv) == SVt_PVHV)) {
      MAGIC *mg;
      if (SvMAGICAL(tsv)) {
        mg = mg_find(tsv,'P');
        if (mg) {
          sv = mg->mg_obj;
          if (sv_isobject(sv)) {
	    tsv = (SV*)SvRV(sv);
            tmp = SvIV(tsv);
          }
        }
      } else {
        return SWIG_ERROR;
      }
    } else {
      tmp = SvIV(tsv);
    }
    voidptr = INT2PTR(void *,tmp);
  } else if (! SvOK(sv)) {            /* Check for undef */
    *(ptr) = (void *) 0;
    return (flags & SWIG_POINTER_NO_NULL) ? SWIG_NullReferenceError : SWIG_OK;
  } else if (SvTYPE(sv) == SVt_RV) {  /* Check for NULL pointer */
    if (!SvROK(sv)) {
      /* In Perl 5.12 and later, SVt_RV == SVt_IV, so sv could be a valid integer value.  */
      if (SvIOK(sv)) {
        return SWIG_ERROR;
      } else {
        /* NULL pointer (reference to undef). */
        *(ptr) = (void *) 0;
        return SWIG_OK;
      }
    } else {
      return SWIG_ERROR;
    }
  } else {                            /* Don't know what it is */
    return SWIG_ERROR;
  }
  if (_t) {
    /* Now see if the types match */
    char *_c = HvNAME(SvSTASH(SvRV(sv)));
    tc = SWIG_TypeProxyCheck(_c,_t);
#ifdef SWIG_DIRECTORS
    if (!tc && !sv_derived_from(sv,SWIG_Perl_TypeProxyName(_t))) {
#else
    if (!tc) {
#endif
      return SWIG_ERROR;
    }
    {
      int newmemory = 0;
      *ptr = SWIG_TypeCast(tc,voidptr,&newmemory);
      if (newmemory == SWIG_CAST_NEW_MEMORY) {
        assert(own); /* badly formed typemap which will lead to a memory leak - it must set and use own to delete *ptr */
        if (own)
          *own = *own | SWIG_CAST_NEW_MEMORY;
      }
    }
  } else {
    *ptr = voidptr;
  }

  /* 
   *  DISOWN implementation: we need a perl guru to check this one.
   */
  if (tsv && ((flags & SWIG_POINTER_DISOWN) || check_owned_pointer_release)) {
    /* 
     *  almost copy paste code from below SWIG_POINTER_OWN setting
     */
    SV *obj = sv;
    HV *stash = SvSTASH(SvRV(obj));
    GV *gv = *(GV**)hv_fetch(stash, "OWNER", 5, TRUE);
    int owned = 0;
    if (isGV(gv)) {
      HV *hv = GvHVn(gv);
      /*
       * To set ownership (see below), a newSViv(1) entry is added. 
       * Hence, to remove ownership, we delete the entry.
       */
      if (hv_exists_ent(hv, obj, 0)) {
        owned = 1;
        if (flags & SWIG_POINTER_DISOWN) {
          hv_delete_ent(hv, obj, 0, 0);
        }
      }
    }
    if (check_owned_pointer_release && !owned) {
      return SWIG_ERROR_RELEASE_NOT_OWNED;
    }
  }

  if (tsv && (flags & SWIG_POINTER_CLEAR)) {
    SvIV_set(tsv, 0);
  }

  return SWIG_OK;
}

SWIGRUNTIME int
SWIG_Perl_ConvertPtr(SWIG_MAYBE_PERL_OBJECT SV *sv, void **ptr, swig_type_info *_t, int flags) {
  return SWIG_Perl_ConvertPtrAndOwn(sv, ptr, _t, flags, 0);
}

SWIGRUNTIME void
SWIG_Perl_MakePtr(SWIG_MAYBE_PERL_OBJECT SV *sv, void *ptr, swig_type_info *t, int flags) {
  if (ptr && (flags & (SWIG_SHADOW | SWIG_POINTER_OWN))) {
    SV *self;
    SV *obj=newSV(0);
    HV *hash=newHV();
    HV *stash;
    sv_setref_pv(obj, SWIG_Perl_TypeProxyName(t), ptr);
    stash=SvSTASH(SvRV(obj));
    if (flags & SWIG_POINTER_OWN) {
      HV *hv;
      GV *gv = *(GV**)hv_fetch(stash, "OWNER", 5, TRUE);
      if (!isGV(gv))
        gv_init(gv, stash, "OWNER", 5, FALSE);
      hv=GvHVn(gv);
      hv_store_ent(hv, obj, newSViv(1), 0);
    }
    sv_magic((SV *)hash, (SV *)obj, 'P', Nullch, 0);
    SvREFCNT_dec(obj);
    self=newRV_noinc((SV *)hash);
    sv_setsv(sv, self);
    SvREFCNT_dec((SV *)self);
    sv_bless(sv, stash);
  }
  else {
    sv_setref_pv(sv, SWIG_Perl_TypeProxyName(t), ptr);
  }
}

SWIGRUNTIMEINLINE SV *
SWIG_Perl_NewPointerObj(SWIG_MAYBE_PERL_OBJECT void *ptr, swig_type_info *t, int flags) {
  SV *result = sv_newmortal();
  SWIG_MakePtr(result, ptr, t, flags);
  return result;
}

SWIGRUNTIME void
SWIG_Perl_MakePackedObj(SWIG_MAYBE_PERL_OBJECT SV *sv, void *ptr, int sz, swig_type_info *type) {
  char result[1024];
  char *r = result;
  if ((2*sz + 1 + strlen(SWIG_Perl_TypeProxyName(type))) > 1000) return;
  *(r++) = '_';
  r = SWIG_PackData(r,ptr,sz);
  strcpy(r,SWIG_Perl_TypeProxyName(type));
  sv_setpv(sv, result);
}

SWIGRUNTIME SV *
SWIG_Perl_NewPackedObj(SWIG_MAYBE_PERL_OBJECT void *ptr, int sz, swig_type_info *type) {
  SV *result = sv_newmortal();
  SWIG_Perl_MakePackedObj(result, ptr, sz, type);
  return result;
}

/* Convert a packed pointer value */
SWIGRUNTIME int
SWIG_Perl_ConvertPacked(SWIG_MAYBE_PERL_OBJECT SV *obj, void *ptr, int sz, swig_type_info *ty) {
  swig_cast_info *tc;
  const char  *c = 0;

  if ((!obj) || (!SvOK(obj))) return SWIG_ERROR;
  c = SvPV_nolen(obj);
  /* Pointer values must start with leading underscore */
  if (*c != '_') return SWIG_ERROR;
  c++;
  c = SWIG_UnpackData(c,ptr,sz);
  if (ty) {
    tc = SWIG_TypeCheck(c,ty);
    if (!tc) return SWIG_ERROR;
  }
  return SWIG_OK;
}


/* Macros for low-level exception handling */
#define SWIG_croak(x)    { SWIG_Error(SWIG_RuntimeError, x); SWIG_fail; }


typedef XSPROTO(SwigPerlWrapper);
typedef SwigPerlWrapper *SwigPerlWrapperPtr;

/* Structure for command table */
typedef struct {
  const char         *name;
  SwigPerlWrapperPtr  wrapper;
} swig_command_info;

/* Information for constant table */

#define SWIG_INT     1
#define SWIG_FLOAT   2
#define SWIG_STRING  3
#define SWIG_POINTER 4
#define SWIG_BINARY  5

/* Constant information structure */
typedef struct swig_constant_info {
    int              type;
    const char      *name;
    long             lvalue;
    double           dvalue;
    void            *pvalue;
    swig_type_info **ptype;
} swig_constant_info;


/* Structure for variable table */
typedef struct {
  const char   *name;
  SwigMagicFunc   set;
  SwigMagicFunc   get;
  swig_type_info  **type;
} swig_variable_info;

/* Magic variable code */
#ifdef __cplusplus
#  define swig_create_magic(s,a,b,c) _swig_create_magic(s,const_cast<char*>(a),b,c)
#else
#  define swig_create_magic(s,a,b,c) _swig_create_magic(s,(char*)(a),b,c)
#endif
#ifndef MULTIPLICITY
SWIGRUNTIME void _swig_create_magic(SV *sv, char *name, int (*set)(SV *, MAGIC *), int (*get)(SV *,MAGIC *))
#else
SWIGRUNTIME void _swig_create_magic(SV *sv, char *name, int (*set)(struct interpreter*, SV *, MAGIC *), int (*get)(struct interpreter*, SV *,MAGIC *))
#endif
{
  MAGIC *mg;
  sv_magic(sv,sv,'U',name,(I32)strlen(name));
  mg = mg_find(sv,'U');
  mg->mg_virtual = (MGVTBL *) malloc(sizeof(MGVTBL));
  mg->mg_virtual->svt_get = (SwigMagicFunc) get;
  mg->mg_virtual->svt_set = (SwigMagicFunc) set;
  mg->mg_virtual->svt_len = 0;
  mg->mg_virtual->svt_clear = 0;
  mg->mg_virtual->svt_free = 0;
}


SWIGRUNTIME swig_module_info *
SWIG_Perl_GetModule(void *SWIGUNUSEDPARM(clientdata)) {
  static void *type_pointer = (void *)0;
  SV *pointer;

  /* first check if pointer already created */
  if (!type_pointer) {
    pointer = get_sv("swig_runtime_data::type_pointer" SWIG_RUNTIME_VERSION SWIG_TYPE_TABLE_NAME, FALSE | GV_ADDMULTI);
    if (pointer && SvOK(pointer)) {
      type_pointer = INT2PTR(swig_type_info **, SvIV(pointer));
    }
  }

  return (swig_module_info *) type_pointer;
}

SWIGRUNTIME void
SWIG_Perl_SetModule(swig_module_info *module) {
  SV *pointer;

  /* create a new pointer */
  pointer = get_sv("swig_runtime_data::type_pointer" SWIG_RUNTIME_VERSION SWIG_TYPE_TABLE_NAME, TRUE | GV_ADDMULTI);
  sv_setiv(pointer, PTR2IV(module));
}

#ifdef __cplusplus
}
#endif

/* Workaround perl5 global namespace pollution. Note that undefining library
 * functions like fopen will not solve the problem on all platforms as fopen
 * might be a macro on Windows but not necessarily on other operating systems. */
#ifdef do_open
  #undef do_open
#endif
#ifdef do_close
  #undef do_close
#endif
#ifdef do_exec
  #undef do_exec
#endif
#ifdef scalar
  #undef scalar
#endif
#ifdef list
  #undef list
#endif
#ifdef apply
  #undef apply
#endif
#ifdef convert
  #undef convert
#endif
#ifdef Error
  #undef Error
#endif
#ifdef form
  #undef form
#endif
#ifdef vform
  #undef vform
#endif
#ifdef LABEL
  #undef LABEL
#endif
#ifdef METHOD
  #undef METHOD
#endif
#ifdef Move
  #undef Move
#endif
#ifdef yylex
  #undef yylex
#endif
#ifdef yyparse
  #undef yyparse
#endif
#ifdef yyerror
  #undef yyerror
#endif
#ifdef invert
  #undef invert
#endif
#ifdef ref
  #undef ref
#endif
#ifdef read
  #undef read
#endif
#ifdef write
  #undef write
#endif
#ifdef eof
  #undef eof
#endif
#ifdef close
  #undef close
#endif
#ifdef rewind
  #undef rewind
#endif
#ifdef free
  #undef free
#endif
#ifdef malloc
  #undef malloc
#endif
#ifdef calloc
  #undef calloc
#endif
#ifdef Stat
  #undef Stat
#endif
#ifdef check
  #undef check
#endif
#ifdef seekdir
  #undef seekdir
#endif
#ifdef open
  #undef open
#endif
#ifdef readdir
  #undef readdir
#endif
#ifdef bind
  #undef bind
#endif
#ifdef access
  #undef access
#endif
#ifdef stat
  #undef stat
#endif
#ifdef seed
  #undef seed
#endif

#ifdef bool
  /* Leave if macro is from C99 stdbool.h */
  #ifndef __bool_true_false_are_defined
    #undef bool
  #endif
#endif




#define SWIG_exception_fail(code, msg) do { SWIG_Error(code, msg); SWIG_fail; } while(0) 

#define SWIG_contract_assert(expr, msg) do { if (!(expr)) { SWIG_Error(SWIG_RuntimeError, msg); SWIG_fail; } } while (0) 



#ifdef seed
  #undef seed
#endif


/* -------- TYPES TABLE (BEGIN) -------- */

#define SWIGTYPE_p_char swig_types[0]
#define SWIGTYPE_p_derivated_lemma swig_types[1]
#define SWIGTYPE_p_derivation_formatter swig_types[2]
#define SWIGTYPE_p_derivator swig_types[3]
#define SWIGTYPE_p_difference_type swig_types[4]
#define SWIGTYPE_p_guesser_mode swig_types[5]
#define SWIGTYPE_p_morpho swig_types[6]
#define SWIGTYPE_p_size_type swig_types[7]
#define SWIGTYPE_p_std__out_of_range swig_types[8]
#define SWIGTYPE_p_std__vectorT_derivated_lemma_t swig_types[9]
#define SWIGTYPE_p_std__vectorT_int_t swig_types[10]
#define SWIGTYPE_p_std__vectorT_std__string_t swig_types[11]
#define SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t swig_types[12]
#define SWIGTYPE_p_std__vectorT_tagged_form_t swig_types[13]
#define SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t swig_types[14]
#define SWIGTYPE_p_std__vectorT_tagged_lemma_t swig_types[15]
#define SWIGTYPE_p_std__vectorT_token_range_t swig_types[16]
#define SWIGTYPE_p_tagged_form swig_types[17]
#define SWIGTYPE_p_tagged_lemma swig_types[18]
#define SWIGTYPE_p_tagged_lemma_forms swig_types[19]
#define SWIGTYPE_p_tagger swig_types[20]
#define SWIGTYPE_p_tagset_converter swig_types[21]
#define SWIGTYPE_p_token_range swig_types[22]
#define SWIGTYPE_p_tokenizer swig_types[23]
#define SWIGTYPE_p_value_type swig_types[24]
#define SWIGTYPE_p_version swig_types[25]
static swig_type_info *swig_types[27];
static swig_module_info swig_module = {swig_types, 26, 0, 0, 0, 0};
#define SWIG_TypeQuery(name) SWIG_TypeQueryModule(&swig_module, &swig_module, name)
#define SWIG_MangledTypeQuery(name) SWIG_MangledTypeQueryModule(&swig_module, &swig_module, name)

/* -------- TYPES TABLE (END) -------- */

#define SWIG_init    boot_Ufal__MorphoDiTa

#define SWIG_name   "Ufal::MorphoDiTac::boot_Ufal__MorphoDiTa"
#define SWIG_prefix "Ufal::MorphoDiTac::"

#ifdef __cplusplus
#include <utility>
/* SwigValueWrapper is described in swig.swg */
template<typename T> class SwigValueWrapper {
  struct SwigSmartPointer {
    T *ptr;
    SwigSmartPointer(T *p) : ptr(p) { }
    ~SwigSmartPointer() { delete ptr; }
    SwigSmartPointer& operator=(SwigSmartPointer& rhs) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = rhs.ptr; rhs.ptr = 0; return *this; }
    void reset(T *p) { T* oldptr = ptr; ptr = 0; delete oldptr; ptr = p; }
  } pointer;
  SwigValueWrapper& operator=(const SwigValueWrapper<T>& rhs);
  SwigValueWrapper(const SwigValueWrapper<T>& rhs);
public:
  SwigValueWrapper() : pointer(0) { }
  SwigValueWrapper& operator=(const T& t) { SwigSmartPointer tmp(new T(t)); pointer = tmp; return *this; }
#if __cplusplus >=201103L
  SwigValueWrapper& operator=(T&& t) { SwigSmartPointer tmp(new T(std::move(t))); pointer = tmp; return *this; }
  operator T&&() const { return std::move(*pointer.ptr); }
#else
  operator T&() const { return *pointer.ptr; }
#endif
  T *operator&() const { return pointer.ptr; }
  static void reset(SwigValueWrapper& t, T *p) { t.pointer.reset(p); }
};

/*
 * SwigValueInit() is a generic initialisation solution as the following approach:
 * 
 *       T c_result = T();
 * 
 * doesn't compile for all types for example:
 * 
 *       unsigned int c_result = unsigned int();
 */
template <typename T> T SwigValueInit() {
  return T();
}

#if __cplusplus >=201103L
# define SWIG_STD_MOVE(OBJ) std::move(OBJ)
#else
# define SWIG_STD_MOVE(OBJ) OBJ
#endif

#endif


#define SWIG_as_voidptr(a) const_cast< void * >(static_cast< const void * >(a)) 
#define SWIG_as_voidptrptr(a) ((void)SWIG_as_voidptr(*a),reinterpret_cast< void** >(a)) 


#include <stdexcept>


#ifdef __cplusplus
extern "C"
#endif
#ifndef MULTIPLICITY
SWIGEXPORT void SWIG_init (CV* cv);
#else
SWIGEXPORT void SWIG_init (pTHXo_ CV* cv);
#endif


#include <string>


#include <typeinfo>
#include <stdexcept>


#include <string>

double SwigSvToNumber(SV* sv) {
    return SvIOK(sv) ? double(SvIVX(sv)) : SvNVX(sv);
}
std::string SwigSvToString(SV* sv) {
    STRLEN len;
    char *ptr = SvPVutf8(sv, len);
    return std::string(ptr, len);
}
void SwigSvFromString(SV* sv, const std::string& s) {
    sv_setpvn(sv,s.data(),s.size());
    SvUTF8_on(sv);
}


#include <vector>


#include <algorithm>


#include "morphodita.h"
using namespace ufal::morphodita;


#include <limits.h>
#if !defined(SWIG_NO_LLONG_MAX)
# if !defined(LLONG_MAX) && defined(__GNUC__) && defined (__LONG_LONG_MAX__)
#   define LLONG_MAX __LONG_LONG_MAX__
#   define LLONG_MIN (-LLONG_MAX - 1LL)
#   define ULLONG_MAX (LLONG_MAX * 2ULL + 1ULL)
# endif
#endif


#include <errno.h>


#include <stdlib.h>
#ifdef _MSC_VER
# ifndef strtoull
#  define strtoull _strtoui64
# endif
# ifndef strtoll
#  define strtoll _strtoi64
# endif
#endif


SWIGINTERN int
SWIG_AsVal_double SWIG_PERL_DECL_ARGS_2(SV *obj, double *val)
{
  if (SvNIOK(obj)) {
    if (val) *val = SvNV(obj);
    return SWIG_OK;
  } else if (SvIOK(obj)) {
    if (val) *val = (double) SvIV(obj);
    return SWIG_AddCast(SWIG_OK);
  } else {
    const char *nptr = SvPV_nolen(obj);
    if (nptr) {
      char *endptr;
      double v;
      errno = 0;
      v = strtod(nptr, &endptr);
      if (errno == ERANGE) {
	errno = 0;
	return SWIG_OverflowError;
      } else {
	if (*endptr == '\0') {
	  if (val) *val = v;
	  return SWIG_Str2NumCast(SWIG_OK);
	}
      }
    }
  }
  return SWIG_TypeError;
}


#include <float.h>


#include <math.h>


SWIGINTERNINLINE int
SWIG_CanCastAsInteger(double *d, double min, double max) {
  double x = *d;
  if ((min <= x && x <= max)) {
   double fx, cx, rd;
   errno = 0;
   fx = floor(x);
   cx = ceil(x);
   rd =  ((x - fx) < 0.5) ? fx : cx; /* simple rint */
   if ((errno == EDOM) || (errno == ERANGE)) {
     errno = 0;
   } else {
     double summ, reps, diff;
     if (rd < x) {
       diff = x - rd;
     } else if (rd > x) {
       diff = rd - x;
     } else {
       return 1;
     }
     summ = rd + x;
     reps = diff/summ;
     if (reps < 8*DBL_EPSILON) {
       *d = rd;
       return 1;
     }
   }
  }
  return 0;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_long SWIG_PERL_DECL_ARGS_2(SV *obj, unsigned long *val) 
{
  if (SvUOK(obj)) {
    UV v = SvUV(obj);
    if (UVSIZE <= sizeof(*val) || v <= ULONG_MAX) {
      if (val) *val = v;
      return SWIG_OK;
    }
    return SWIG_OverflowError;
  } else if (SvIOK(obj)) {
    IV v = SvIV(obj);
    if (v >= 0 && (IVSIZE <= sizeof(*val) || v <= ULONG_MAX)) {
      if (val) *val = v;
      return SWIG_OK;
    }
    return SWIG_OverflowError;
  } else {
    int dispatch = 0;
    const char *nptr = SvPV_nolen(obj);
    if (nptr) {
      char *endptr;
      unsigned long v;
      errno = 0;
      v = strtoul(nptr, &endptr,0);
      if (errno == ERANGE) {
	errno = 0;
	return SWIG_OverflowError;
      } else {
	if (*endptr == '\0') {
	  if (val) *val = v;
	  return SWIG_Str2NumCast(SWIG_OK);
	}
      }
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double SWIG_PERL_CALL_ARGS_2(obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, ULONG_MAX)) {
	if (val) *val = (unsigned long)(d);
	return res;
      }
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_unsigned_SS_int SWIG_PERL_DECL_ARGS_2(SV * obj, unsigned int *val)
{
  unsigned long v;
  int res = SWIG_AsVal_unsigned_SS_long SWIG_PERL_CALL_ARGS_2(obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v > UINT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< unsigned int >(v);
    }
  }  
  return res;
}


SWIGINTERN int
SWIG_AsVal_long SWIG_PERL_DECL_ARGS_2(SV *obj, long* val)
{
  if (SvUOK(obj)) {
    UV v = SvUV(obj);
    if (UVSIZE < sizeof(*val) || v <= LONG_MAX) {
      if (val) *val = v;
      return SWIG_OK;
    }
    return SWIG_OverflowError;
  } else if (SvIOK(obj)) {
    IV v = SvIV(obj);
    if (IVSIZE <= sizeof(*val) || (v >= LONG_MIN && v <= LONG_MAX)) {
      if(val) *val = v;
      return SWIG_OK;
    }
    return SWIG_OverflowError;
  } else {
    int dispatch = 0;
    const char *nptr = SvPV_nolen(obj);
    if (nptr) {
      char *endptr;
      long v;
      errno = 0;
      v = strtol(nptr, &endptr,0);
      if (errno == ERANGE) {
	errno = 0;
	return SWIG_OverflowError;
      } else {
	if (*endptr == '\0') {
	  if (val) *val = v;
	  return SWIG_Str2NumCast(SWIG_OK);
	}
      }
    }
    if (!dispatch) {
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double SWIG_PERL_CALL_ARGS_2(obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, LONG_MIN, LONG_MAX)) {
	if (val) *val = (long)(d);
	return res;
      }
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsVal_int SWIG_PERL_DECL_ARGS_2(SV * obj, int *val)
{
  long v;
  int res = SWIG_AsVal_long SWIG_PERL_CALL_ARGS_2(obj, &v);
  if (SWIG_IsOK(res)) {
    if ((v < INT_MIN || v > INT_MAX)) {
      return SWIG_OverflowError;
    } else {
      if (val) *val = static_cast< int >(v);
    }
  }  
  return res;
}


SWIGINTERNINLINE SV *
SWIG_From_unsigned_SS_long  SWIG_PERL_DECL_ARGS_1(unsigned long value)
{
  SV *sv;
  if (UVSIZE >= sizeof(value) || value <= UV_MAX)
    sv = newSVuv(value);
  else
    sv = newSVpvf("%lu", value);
  return sv_2mortal(sv);
}


SWIGINTERNINLINE SV *
SWIG_From_unsigned_SS_int  SWIG_PERL_DECL_ARGS_1(unsigned int value)
{    
  return SWIG_From_unsigned_SS_long  SWIG_PERL_CALL_ARGS_1(value);
}


SWIGINTERNINLINE SV *
SWIG_From_bool  SWIG_PERL_DECL_ARGS_1(bool value)
{
  return boolSV(value);
}

SWIGINTERN int std_vector_Sl_int_Sg__pop(std::vector< int > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                int x = self->back();
                self->pop_back();
                return x;
            }

SWIGINTERNINLINE SV *
SWIG_From_long  SWIG_PERL_DECL_ARGS_1(long value)
{
  SV *sv;
  if (IVSIZE >= sizeof(value) || (value >= IV_MIN && value <= IV_MAX))
    sv = newSViv(value);
  else
    sv = newSVpvf("%ld", value);
  return sv_2mortal(sv);
}


SWIGINTERNINLINE SV *
SWIG_From_int  SWIG_PERL_DECL_ARGS_1(int value)
{    
  return SWIG_From_long  SWIG_PERL_CALL_ARGS_1(value);
}

SWIGINTERN int std_vector_Sl_int_Sg__get(std::vector< int > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_int_Sg__set(std::vector< int > *self,int i,int x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }

SWIGINTERN swig_type_info*
SWIG_pchar_descriptor(void)
{
  static swig_type_info* info = 0;
  if (!info) {
    info = SWIG_TypeQuery("_p_char");
  }
  return info;
}


SWIGINTERN int
SWIG_AsCharPtrAndSize(SV *obj, char** cptr, size_t* psize, int *alloc)
{
  if (SvMAGICAL(obj)) {
     SV *tmp = sv_newmortal();
     SvSetSV(tmp, obj);
     obj = tmp;
  }
  if (SvPOK(obj)) {
    STRLEN len = 0;
    char *cstr = SvPVutf8(obj, len);
    size_t size = len + 1;
    if (cptr)  {
      if (alloc) {
	if (*alloc == SWIG_NEWOBJ) {
	  *cptr = reinterpret_cast< char* >(memcpy(new char[size], cstr, sizeof(char)*(size)));
	} else {
	  *cptr = cstr;
	  *alloc = SWIG_OLDOBJ;
	}
      }
    }
    if (psize) *psize = size;
    return SWIG_OK;
  } else {
    swig_type_info* pchar_descriptor = SWIG_pchar_descriptor();
    if (pchar_descriptor) {
      char* vptr = 0; 
      if (SWIG_ConvertPtr(obj, (void**)&vptr, pchar_descriptor, 0) == SWIG_OK) {
	if (cptr) *cptr = vptr;
	if (psize) *psize = vptr ? (strlen(vptr) + 1) : 0;
	if (alloc) *alloc = SWIG_OLDOBJ;
	return SWIG_OK;
      }
    }
  }
  return SWIG_TypeError;
}


SWIGINTERN int
SWIG_AsPtr_std_string SWIG_PERL_DECL_ARGS_2(SV * obj, std::string **val) 
{
  char* buf = 0 ; size_t size = 0; int alloc = SWIG_OLDOBJ;
  if (SWIG_IsOK((SWIG_AsCharPtrAndSize(obj, &buf, &size, &alloc)))) {
    if (buf) {
      if (val) *val = new std::string(buf, size - 1);
      if (alloc == SWIG_NEWOBJ) delete[] buf;
      return SWIG_NEWOBJ;
    } else {
      if (val) *val = 0;
      return SWIG_OLDOBJ;
    }
  } else {
    ;
    static swig_type_info *descriptor = SWIG_TypeQuery("std::string" " *");
    if (descriptor) {
      std::string *vptr;
      int res = SWIG_ConvertPtr(obj, (void**)&vptr, descriptor, 0);
      if (SWIG_IsOK(res) && val) *val = vptr;
      return res;
    }
  }
  return SWIG_ERROR;
}

SWIGINTERN std::string std_vector_Sl_std_string_Sg__pop(std::vector< std::string > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                std::string x = self->back();
                self->pop_back();
                return x;
            }

SWIGINTERNINLINE SV *
SWIG_FromCharPtrAndSize(const char* carray, size_t size)
{
  SV *obj = sv_newmortal();
  if (carray) {
    sv_setpvn(obj, carray, size);
    SvUTF8_on(obj);
  } else {
    sv_setsv(obj, &PL_sv_undef);
  }
  return obj;
}


SWIGINTERNINLINE SV *
SWIG_From_std_string  SWIG_PERL_DECL_ARGS_1(const std::string& s)
{
  return SWIG_FromCharPtrAndSize(s.data(), s.size());
}

SWIGINTERN std::string std_vector_Sl_std_string_Sg__get(std::vector< std::string > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_std_string_Sg__set(std::vector< std::string > *self,int i,std::string x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN tagged_form std_vector_Sl_tagged_form_Sg__pop(std::vector< tagged_form > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                tagged_form x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN tagged_form &std_vector_Sl_tagged_form_Sg__get(std::vector< tagged_form > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_tagged_form_Sg__set(std::vector< tagged_form > *self,int i,tagged_form const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN tagged_lemma std_vector_Sl_tagged_lemma_Sg__pop(std::vector< tagged_lemma > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                tagged_lemma x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN tagged_lemma &std_vector_Sl_tagged_lemma_Sg__get(std::vector< tagged_lemma > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_tagged_lemma_Sg__set(std::vector< tagged_lemma > *self,int i,tagged_lemma const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN std::vector< tagged_lemma > std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__pop(std::vector< std::vector< tagged_lemma > > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                std::vector< tagged_lemma > x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN std::vector< tagged_lemma > &std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__get(std::vector< std::vector< tagged_lemma > > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__set(std::vector< std::vector< tagged_lemma > > *self,int i,std::vector< tagged_lemma > const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN tagged_lemma_forms std_vector_Sl_tagged_lemma_forms_Sg__pop(std::vector< tagged_lemma_forms > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                tagged_lemma_forms x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN tagged_lemma_forms &std_vector_Sl_tagged_lemma_forms_Sg__get(std::vector< tagged_lemma_forms > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_tagged_lemma_forms_Sg__set(std::vector< tagged_lemma_forms > *self,int i,tagged_lemma_forms const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }

#if defined(LLONG_MAX) && !defined(SWIG_LONG_LONG_AVAILABLE)
#  define SWIG_LONG_LONG_AVAILABLE
#endif


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERN int
SWIG_AsVal_unsigned_SS_long_SS_long SWIG_PERL_DECL_ARGS_2(SV *obj, unsigned long long *val)
{
  if (SvUOK(obj)) {
    /* pretty sure this should be conditional on
     * (UVSIZE <= sizeof(*val) || v <= ULLONG_MAX) */
    if (val) *val = SvUV(obj);
    return SWIG_OK;
  } else if (SvIOK(obj)) {
    IV v = SvIV(obj);
    if (v >= 0 && (IVSIZE <= sizeof(*val) || v <= ULLONG_MAX)) {
      if (val) *val = v;
      return SWIG_OK;
    } else {
      return SWIG_OverflowError;
    }
  } else {
    int dispatch = 0;
    const char *nptr = SvPV_nolen(obj);
    if (nptr) {
      char *endptr;
      unsigned long long v;
      errno = 0;
      v = strtoull(nptr, &endptr,0);
      if (errno == ERANGE) {
	errno = 0;
	return SWIG_OverflowError;
      } else {
	if (*endptr == '\0') {
	  if (val) *val = v;
	  return SWIG_Str2NumCast(SWIG_OK);
	}
      }
    }
    if (!dispatch) {
      const double mant_max = 1LL << DBL_MANT_DIG;
      double d;
      int res = SWIG_AddCast(SWIG_AsVal_double SWIG_PERL_CALL_ARGS_2(obj,&d));
      if (SWIG_IsOK(res) && SWIG_CanCastAsInteger(&d, 0, mant_max)) {
	if (val) *val = (unsigned long long)(d);
	return res;
      }
    }
  }
  return SWIG_TypeError;
}
#endif


SWIGINTERNINLINE int
SWIG_AsVal_size_t SWIG_PERL_DECL_ARGS_2(SV * obj, size_t *val)
{
  int res = SWIG_TypeError;
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(size_t) <= sizeof(unsigned long)) {
#endif
    unsigned long v;
    res = SWIG_AsVal_unsigned_SS_long SWIG_PERL_CALL_ARGS_2(obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else if (sizeof(size_t) <= sizeof(unsigned long long)) {
    unsigned long long v;
    res = SWIG_AsVal_unsigned_SS_long_SS_long SWIG_PERL_CALL_ARGS_2(obj, val ? &v : 0);
    if (SWIG_IsOK(res) && val) *val = static_cast< size_t >(v);
  }
#endif
  return res;
}


#include <stdio.h>
#if (defined(_MSC_VER) && (_MSC_VER < 1900)) || defined(__BORLANDC__) || defined(_WATCOM)
# ifndef snprintf
#  define snprintf _snprintf
# endif
#endif


#ifdef SWIG_LONG_LONG_AVAILABLE
SWIGINTERNINLINE SV *
SWIG_From_unsigned_SS_long_SS_long  SWIG_PERL_DECL_ARGS_1(unsigned long long value)
{
  SV *sv;
  if (UVSIZE >= sizeof(value) || value <= UV_MAX)
    sv = newSVuv((UV)(value));
  else {
    //sv = newSVpvf("%llu", value); doesn't work in non 64bit Perl
    char temp[256];
    SWIG_snprintf(temp, sizeof(temp), "%llu", value);
    sv = newSVpv(temp, 0);
  }
  return sv_2mortal(sv);
}
#endif


SWIGINTERNINLINE SV *
SWIG_From_size_t  SWIG_PERL_DECL_ARGS_1(size_t value)
{    
#ifdef SWIG_LONG_LONG_AVAILABLE
  if (sizeof(size_t) <= sizeof(unsigned long)) {
#endif
    return SWIG_From_unsigned_SS_long  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned long >(value));
#ifdef SWIG_LONG_LONG_AVAILABLE
  } else {
    /* assume sizeof(size_t) <= sizeof(unsigned long long) */
    return SWIG_From_unsigned_SS_long_SS_long  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned long long >(value));
  }
#endif
}

SWIGINTERN token_range std_vector_Sl_token_range_Sg__pop(std::vector< token_range > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                token_range x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN token_range &std_vector_Sl_token_range_Sg__get(std::vector< token_range > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_token_range_Sg__set(std::vector< token_range > *self,int i,token_range const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN derivated_lemma std_vector_Sl_derivated_lemma_Sg__pop(std::vector< derivated_lemma > *self){
                if (self->size() == 0)
                    throw std::out_of_range("pop from empty vector");
                derivated_lemma x = self->back();
                self->pop_back();
                return x;
            }
SWIGINTERN derivated_lemma &std_vector_Sl_derivated_lemma_Sg__get(std::vector< derivated_lemma > *self,int i){
                int size = int(self->size());
                if (i>=0 && i<size)
                    return (*self)[i];
                else
                    throw std::out_of_range("vector index out of range");
            }
SWIGINTERN void std_vector_Sl_derivated_lemma_Sg__set(std::vector< derivated_lemma > *self,int i,derivated_lemma const &x){
                int size = int(self->size());
                if (i>=0 && i<size)
                    (*self)[i] = x;
                else
                    throw std::out_of_range("vector index out of range");
            }



SWIGINTERN void tokenizer_set_text(tokenizer *self,char const *text){
      self->set_text(text, true);
    }
SWIGINTERN bool tokenizer_next_sentence(tokenizer *self,std::vector< std::string > *forms,std::vector< token_range > *tokens){
      if (!forms) return self->next_sentence(NULL, tokens);

      std::vector<string_piece> string_pieces;
      bool result = self->next_sentence(&string_pieces, tokens);
      forms->resize(string_pieces.size());
      for (unsigned i = 0; i < string_pieces.size(); i++)
        forms->operator[](i).assign(string_pieces[i].str, string_pieces[i].len);
      return result;
    }
SWIGINTERN std::string morpho_raw_lemma(morpho const *self,char const *lemma){
      return std::string(lemma, self->raw_lemma_len(lemma));
    }
SWIGINTERN std::string morpho_lemma_id(morpho const *self,char const *lemma){
      return std::string(lemma, self->lemma_id_len(lemma));
    }
SWIGINTERN std::string morpho_raw_form(morpho const *self,char const *form){
      return std::string(form, self->raw_form_len(form));
    }
SWIGINTERN void tagger_tag__SWIG_0(tagger const *self,std::vector< std::string > const &forms,std::vector< tagged_lemma > &tags,int guesser=-1){
      std::vector<string_piece> string_pieces;
      string_pieces.reserve(forms.size());
      for (auto&& form : forms)
        string_pieces.emplace_back(form);
      self->tag(string_pieces, tags, morpho::guesser_mode(guesser));
    }
SWIGINTERN void tagger_tagAnalyzed(tagger const *self,std::vector< std::string > const &forms,std::vector< std::vector< tagged_lemma > > const &analyses,std::vector< int > &tags){
      std::vector<string_piece> string_pieces;
      string_pieces.reserve(forms.size());
      for (auto&& form : forms)
        string_pieces.emplace_back(form);
      self->tag_analyzed(string_pieces, analyses, tags);
    }
SWIGINTERN std::string derivation_formatter_format_derivation(derivation_formatter const *self,char const *lemma){
      std::string derivation(lemma);
      self->format_derivation(derivation);
      return derivation;
    }
#ifdef __cplusplus
extern "C" {
#endif

#define MAGIC_CLASS
SWIGCLASS_STATIC int swig_magic_readonly(pTHX_ SV *SWIGUNUSEDPARM(sv), MAGIC *SWIGUNUSEDPARM(mg)) {
    MAGIC_PPERL
    croak("Value is read-only.");
    return 0;
}

#ifdef __cplusplus
}
#endif

#ifdef __cplusplus
extern "C" {
#endif
XS(_wrap_new_Indices__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< int > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Indices(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Indices" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< int > *)new std::vector< int >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Indices__SWIG_1) {
  {
    int argvi = 0;
    std::vector< int > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_Indices();");
    }
    result = (std::vector< int > *)new std::vector< int >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_Indices__SWIG_2) {
  {
    unsigned int arg1 ;
    int arg2 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    std::vector< int > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_Indices(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Indices" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "new_Indices" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    result = (std::vector< int > *)new std::vector< int >(arg1,arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Indices__SWIG_3) {
  {
    std::vector< int > *arg1 = 0 ;
    std::vector< int > temp1 ;
    std::vector< int > *v1 ;
    int argvi = 0;
    std::vector< int > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Indices(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_int_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_Indices. "
          "Expected an array of ""int");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvIOK(*tv)) {
            temp1.push_back((int)SvIVX(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_Indices. "
              "Expected an array of ""int");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_Indices. "
          "Expected an array of ""int");
      }
    }
    result = (std::vector< int > *)new std::vector< int >((std::vector< int > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_int_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Indices) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< int >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_int_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  SV **tv = av_fetch(av, 0, 0);
                  if (SvIOK(*tv))
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        {
          int res = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Indices__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Indices__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Indices__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Indices__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_Indices'");
  XSRETURN(0);
}


XS(_wrap_Indices_size) {
  {
    std::vector< int > *arg1 = 0 ;
    std::vector< int > temp1 ;
    std::vector< int > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Indices_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_int_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Indices_size. "
          "Expected an array of ""int");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvIOK(*tv)) {
            temp1.push_back((int)SvIVX(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Indices_size. "
              "Expected an array of ""int");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Indices_size. "
          "Expected an array of ""int");
      }
    }
    result = (unsigned int)((std::vector< int > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_empty) {
  {
    std::vector< int > *arg1 = 0 ;
    std::vector< int > temp1 ;
    std::vector< int > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Indices_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_int_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Indices_empty. "
          "Expected an array of ""int");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvIOK(*tv)) {
            temp1.push_back((int)SvIVX(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Indices_empty. "
              "Expected an array of ""int");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Indices_empty. "
          "Expected an array of ""int");
      }
    }
    result = (bool)((std::vector< int > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_clear) {
  {
    std::vector< int > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Indices_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Indices_clear" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_push) {
  {
    std::vector< int > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Indices_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Indices_push" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Indices_push" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    (arg1)->push_back(arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_pop) {
  {
    std::vector< int > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Indices_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Indices_pop" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    try {
      result = (int)std_vector_Sl_int_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_get) {
  {
    std::vector< int > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    int result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Indices_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Indices_get" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Indices_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (int)std_vector_Sl_int_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(result)); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Indices_set) {
  {
    std::vector< int > *arg1 = 0 ;
    int arg2 ;
    int arg3 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int val3 ;
    int ecode3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Indices_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Indices_set" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Indices_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    ecode3 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(2), &val3);
    if (!SWIG_IsOK(ecode3)) {
      SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Indices_set" "', argument " "3"" of type '" "int""'");
    } 
    arg3 = static_cast< int >(val3);
    try {
      std_vector_Sl_int_Sg__set(arg1,arg2,arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Indices) {
  {
    std::vector< int > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Indices(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_int_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Indices" "', argument " "1"" of type '" "std::vector< int > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< int > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Forms__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< std::string > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Forms(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Forms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< std::string > *)new std::vector< std::string >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Forms__SWIG_1) {
  {
    int argvi = 0;
    std::vector< std::string > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_Forms();");
    }
    result = (std::vector< std::string > *)new std::vector< std::string >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_Forms__SWIG_2) {
  {
    unsigned int arg1 ;
    std::string arg2 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< std::string > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_Forms(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Forms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    {
      std::string *ptr = (std::string *)0;
      int res = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res) || !ptr) {
        SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "new_Forms" "', argument " "2"" of type '" "std::string""'"); 
      }
      arg2 = *ptr;
      if (SWIG_IsNewObj(res)) delete ptr;
    }
    result = (std::vector< std::string > *)new std::vector< std::string >(arg1,SWIG_STD_MOVE(arg2));
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Forms__SWIG_3) {
  {
    std::vector< std::string > *arg1 = 0 ;
    std::vector< std::string > temp1 ;
    std::vector< std::string > *v1 ;
    int argvi = 0;
    std::vector< std::string > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Forms(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_Forms. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp1.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_Forms. "
              "Expected an array of ""std::string");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_Forms. "
          "Expected an array of ""std::string");
      }
    }
    result = (std::vector< std::string > *)new std::vector< std::string >((std::vector< std::string > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__string_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Forms) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< std::string >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_std__string_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  SV **tv = av_fetch(av, 0, 0);
                  if (SvPOK(*tv))
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        int res = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), (std::string**)(0));
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Forms__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Forms__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Forms__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Forms__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_Forms'");
  XSRETURN(0);
}


XS(_wrap_Forms_size) {
  {
    std::vector< std::string > *arg1 = 0 ;
    std::vector< std::string > temp1 ;
    std::vector< std::string > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Forms_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Forms_size. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp1.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Forms_size. "
              "Expected an array of ""std::string");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Forms_size. "
          "Expected an array of ""std::string");
      }
    }
    result = (unsigned int)((std::vector< std::string > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_empty) {
  {
    std::vector< std::string > *arg1 = 0 ;
    std::vector< std::string > temp1 ;
    std::vector< std::string > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Forms_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Forms_empty. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp1.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Forms_empty. "
              "Expected an array of ""std::string");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Forms_empty. "
          "Expected an array of ""std::string");
      }
    }
    result = (bool)((std::vector< std::string > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_clear) {
  {
    std::vector< std::string > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Forms_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Forms_clear" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_push) {
  {
    std::vector< std::string > *arg1 = 0 ;
    std::string arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Forms_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Forms_push" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      int res = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res) || !ptr) {
        SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "Forms_push" "', argument " "2"" of type '" "std::string""'"); 
      }
      arg2 = *ptr;
      if (SWIG_IsNewObj(res)) delete ptr;
    }
    (arg1)->push_back(SWIG_STD_MOVE(arg2));
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_pop) {
  {
    std::vector< std::string > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Forms_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Forms_pop" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    try {
      result = std_vector_Sl_std_string_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_get) {
  {
    std::vector< std::string > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Forms_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Forms_get" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Forms_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = std_vector_Sl_std_string_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Forms_set) {
  {
    std::vector< std::string > *arg1 = 0 ;
    int arg2 ;
    std::string arg3 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Forms_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Forms_set" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Forms_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    {
      std::string *ptr = (std::string *)0;
      int res = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(2), &ptr);
      if (!SWIG_IsOK(res) || !ptr) {
        SWIG_exception_fail(SWIG_ArgError((ptr ? res : SWIG_TypeError)), "in method '" "Forms_set" "', argument " "3"" of type '" "std::string""'"); 
      }
      arg3 = *ptr;
      if (SWIG_IsNewObj(res)) delete ptr;
    }
    try {
      std_vector_Sl_std_string_Sg__set(arg1,arg2,SWIG_STD_MOVE(arg3));
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Forms) {
  {
    std::vector< std::string > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Forms(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__string_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Forms" "', argument " "1"" of type '" "std::vector< std::string > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::string > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForm_form_set) {
  {
    tagged_form *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedForm_form_set(self,form);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_form, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForm_form_set" "', argument " "1"" of type '" "tagged_form *""'"); 
    }
    arg1 = reinterpret_cast< tagged_form * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedForm_form_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedForm_form_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->form = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForm_form_get) {
  {
    tagged_form *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForm_form_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_form, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForm_form_get" "', argument " "1"" of type '" "tagged_form *""'"); 
    }
    arg1 = reinterpret_cast< tagged_form * >(argp1);
    result = (std::string *) & ((arg1)->form);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForm_tag_set) {
  {
    tagged_form *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedForm_tag_set(self,tag);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_form, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForm_tag_set" "', argument " "1"" of type '" "tagged_form *""'"); 
    }
    arg1 = reinterpret_cast< tagged_form * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedForm_tag_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedForm_tag_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->tag = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForm_tag_get) {
  {
    tagged_form *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForm_tag_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_form, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForm_tag_get" "', argument " "1"" of type '" "tagged_form *""'"); 
    }
    arg1 = reinterpret_cast< tagged_form * >(argp1);
    result = (std::string *) & ((arg1)->tag);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForm) {
  {
    int argvi = 0;
    tagged_form *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedForm();");
    }
    result = (tagged_form *)new tagged_form();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_form, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedForm) {
  {
    tagged_form *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedForm(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_form, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedForm" "', argument " "1"" of type '" "tagged_form *""'"); 
    }
    arg1 = reinterpret_cast< tagged_form * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForms__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< tagged_form > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedForms(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedForms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< tagged_form > *)new std::vector< tagged_form >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_form_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForms__SWIG_1) {
  {
    int argvi = 0;
    std::vector< tagged_form > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedForms();");
    }
    result = (std::vector< tagged_form > *)new std::vector< tagged_form >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_form_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForms__SWIG_2) {
  {
    unsigned int arg1 ;
    tagged_form *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    std::vector< tagged_form > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_TaggedForms(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedForms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_form,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_TaggedForms" "', argument " "2"" of type '" "tagged_form const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "new_TaggedForms" "', argument " "2"" of type '" "tagged_form const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_form * >(argp2);
    result = (std::vector< tagged_form > *)new std::vector< tagged_form >(arg1,(tagged_form const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_form_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForms__SWIG_3) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    std::vector< tagged_form > temp1 ;
    std::vector< tagged_form > *v1 ;
    int argvi = 0;
    std::vector< tagged_form > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedForms(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_form_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_TaggedForms. "
          "Expected an array of " "tagged_form");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_form* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_form,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_TaggedForms. "
              "Expected an array of " "tagged_form");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_TaggedForms. "
          "Expected an array of " "tagged_form");
      }
    }
    result = (std::vector< tagged_form > *)new std::vector< tagged_form >((std::vector< tagged_form > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_form_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedForms) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< tagged_form >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_tagged_form_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  tagged_form* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_tagged_form,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_tagged_form, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedForms__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedForms__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedForms__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedForms__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_TaggedForms'");
  XSRETURN(0);
}


XS(_wrap_TaggedForms_size) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    std::vector< tagged_form > temp1 ;
    std::vector< tagged_form > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForms_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_form_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedForms_size. "
          "Expected an array of " "tagged_form");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_form* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_form,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedForms_size. "
              "Expected an array of " "tagged_form");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedForms_size. "
          "Expected an array of " "tagged_form");
      }
    }
    result = (unsigned int)((std::vector< tagged_form > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_empty) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    std::vector< tagged_form > temp1 ;
    std::vector< tagged_form > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForms_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_form_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedForms_empty. "
          "Expected an array of " "tagged_form");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_form* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_form,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedForms_empty. "
              "Expected an array of " "tagged_form");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedForms_empty. "
          "Expected an array of " "tagged_form");
      }
    }
    result = (bool)((std::vector< tagged_form > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_clear) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForms_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForms_clear" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_push) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    tagged_form *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedForms_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForms_push" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_form,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedForms_push" "', argument " "2"" of type '" "tagged_form const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedForms_push" "', argument " "2"" of type '" "tagged_form const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_form * >(argp2);
    (arg1)->push_back((tagged_form const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_pop) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tagged_form result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedForms_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForms_pop" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    try {
      result = std_vector_Sl_tagged_form_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj((new tagged_form(result)), SWIGTYPE_p_tagged_form, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_get) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    tagged_form *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedForms_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForms_get" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedForms_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (tagged_form *) &std_vector_Sl_tagged_form_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_form, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedForms_set) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    int arg2 ;
    tagged_form *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: TaggedForms_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedForms_set" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedForms_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_tagged_form,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "TaggedForms_set" "', argument " "3"" of type '" "tagged_form const &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedForms_set" "', argument " "3"" of type '" "tagged_form const &""'"); 
    }
    arg3 = reinterpret_cast< tagged_form * >(argp3);
    try {
      std_vector_Sl_tagged_form_Sg__set(arg1,arg2,(tagged_form const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedForms) {
  {
    std::vector< tagged_form > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedForms(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_form_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedForms" "', argument " "1"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_form > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemma_lemma_set) {
  {
    tagged_lemma *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemma_lemma_set(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemma_lemma_set" "', argument " "1"" of type '" "tagged_lemma *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemma_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemma_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->lemma = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemma_lemma_get) {
  {
    tagged_lemma *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemma_lemma_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemma_lemma_get" "', argument " "1"" of type '" "tagged_lemma *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma * >(argp1);
    result = (std::string *) & ((arg1)->lemma);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemma_tag_set) {
  {
    tagged_lemma *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemma_tag_set(self,tag);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemma_tag_set" "', argument " "1"" of type '" "tagged_lemma *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemma_tag_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemma_tag_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->tag = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemma_tag_get) {
  {
    tagged_lemma *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemma_tag_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemma_tag_get" "', argument " "1"" of type '" "tagged_lemma *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma * >(argp1);
    result = (std::string *) & ((arg1)->tag);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemma) {
  {
    int argvi = 0;
    tagged_lemma *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedLemma();");
    }
    result = (tagged_lemma *)new tagged_lemma();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_lemma, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedLemma) {
  {
    tagged_lemma *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedLemma(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedLemma" "', argument " "1"" of type '" "tagged_lemma *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmas__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedLemmas(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedLemmas" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< tagged_lemma > *)new std::vector< tagged_lemma >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmas__SWIG_1) {
  {
    int argvi = 0;
    std::vector< tagged_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedLemmas();");
    }
    result = (std::vector< tagged_lemma > *)new std::vector< tagged_lemma >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmas__SWIG_2) {
  {
    unsigned int arg1 ;
    tagged_lemma *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_TaggedLemmas(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedLemmas" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_TaggedLemmas" "', argument " "2"" of type '" "tagged_lemma const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "new_TaggedLemmas" "', argument " "2"" of type '" "tagged_lemma const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma * >(argp2);
    result = (std::vector< tagged_lemma > *)new std::vector< tagged_lemma >(arg1,(tagged_lemma const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmas__SWIG_3) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    std::vector< tagged_lemma > temp1 ;
    std::vector< tagged_lemma > *v1 ;
    int argvi = 0;
    std::vector< tagged_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedLemmas(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_TaggedLemmas. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_TaggedLemmas. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_TaggedLemmas. "
          "Expected an array of " "tagged_lemma");
      }
    }
    result = (std::vector< tagged_lemma > *)new std::vector< tagged_lemma >((std::vector< tagged_lemma > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmas) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< tagged_lemma >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  tagged_lemma* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_tagged_lemma,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_tagged_lemma, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmas__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmas__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmas__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmas__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_TaggedLemmas'");
  XSRETURN(0);
}


XS(_wrap_TaggedLemmas_size) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    std::vector< tagged_lemma > temp1 ;
    std::vector< tagged_lemma > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmas_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedLemmas_size. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedLemmas_size. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedLemmas_size. "
          "Expected an array of " "tagged_lemma");
      }
    }
    result = (unsigned int)((std::vector< tagged_lemma > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_empty) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    std::vector< tagged_lemma > temp1 ;
    std::vector< tagged_lemma > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmas_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedLemmas_empty. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedLemmas_empty. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedLemmas_empty. "
          "Expected an array of " "tagged_lemma");
      }
    }
    result = (bool)((std::vector< tagged_lemma > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_clear) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmas_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmas_clear" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_push) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    tagged_lemma *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmas_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmas_push" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemmas_push" "', argument " "2"" of type '" "tagged_lemma const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemmas_push" "', argument " "2"" of type '" "tagged_lemma const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma * >(argp2);
    (arg1)->push_back((tagged_lemma const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_pop) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tagged_lemma result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmas_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmas_pop" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    try {
      result = std_vector_Sl_tagged_lemma_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj((new tagged_lemma(result)), SWIGTYPE_p_tagged_lemma, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_get) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    tagged_lemma *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmas_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmas_get" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedLemmas_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (tagged_lemma *) &std_vector_Sl_tagged_lemma_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_lemma, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmas_set) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    int arg2 ;
    tagged_lemma *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: TaggedLemmas_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmas_set" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedLemmas_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "TaggedLemmas_set" "', argument " "3"" of type '" "tagged_lemma const &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemmas_set" "', argument " "3"" of type '" "tagged_lemma const &""'"); 
    }
    arg3 = reinterpret_cast< tagged_lemma * >(argp3);
    try {
      std_vector_Sl_tagged_lemma_Sg__set(arg1,arg2,(tagged_lemma const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedLemmas) {
  {
    std::vector< tagged_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedLemmas(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedLemmas" "', argument " "1"" of type '" "std::vector< tagged_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Analyses__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< std::vector< tagged_lemma > > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Analyses(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Analyses" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< std::vector< tagged_lemma > > *)new std::vector< std::vector< tagged_lemma > >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Analyses__SWIG_1) {
  {
    int argvi = 0;
    std::vector< std::vector< tagged_lemma > > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_Analyses();");
    }
    result = (std::vector< std::vector< tagged_lemma > > *)new std::vector< std::vector< tagged_lemma > >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_Analyses__SWIG_2) {
  {
    unsigned int arg1 ;
    std::vector< tagged_lemma > *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    std::vector< tagged_lemma > temp2 ;
    std::vector< tagged_lemma > *v2 ;
    int argvi = 0;
    std::vector< std::vector< tagged_lemma > > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_Analyses(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_Analyses" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    {
      if (SWIG_ConvertPtr(ST(1),(void **) &v2, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg2 = v2;
      } else if (SvROK(ST(1))) {
        AV *av = (AV *)SvRV(ST(1));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 2 of new_Analyses. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp2.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 2 of "
              "new_Analyses. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg2 = &temp2;
      } else {
        SWIG_croak("Type error in argument 2 of new_Analyses. "
          "Expected an array of " "tagged_lemma");
      }
    }
    result = (std::vector< std::vector< tagged_lemma > > *)new std::vector< std::vector< tagged_lemma > >(arg1,(std::vector< tagged_lemma > const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Analyses__SWIG_3) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    std::vector< std::vector< tagged_lemma > > temp1 ;
    std::vector< std::vector< tagged_lemma > > *v1 ;
    int argvi = 0;
    std::vector< std::vector< tagged_lemma > > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_Analyses(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_Analyses. "
          "Expected an array of " "std::vector< tagged_lemma >");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        std::vector< tagged_lemma >* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_Analyses. "
              "Expected an array of " "std::vector< tagged_lemma >");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_Analyses. "
          "Expected an array of " "std::vector< tagged_lemma >");
      }
    }
    result = (std::vector< std::vector< tagged_lemma > > *)new std::vector< std::vector< tagged_lemma > >((std::vector< std::vector< tagged_lemma > > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_Analyses) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< std::vector< tagged_lemma > >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  std::vector< tagged_lemma >* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        {
          {
            /* wrapped vector? */
            std::vector< tagged_lemma >* v;
            if (SWIG_ConvertPtr(ST(1),(void **) &v, 
                SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(1))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(1));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  tagged_lemma* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_tagged_lemma,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Analyses__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Analyses__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Analyses__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_Analyses__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_Analyses'");
  XSRETURN(0);
}


XS(_wrap_Analyses_size) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    std::vector< std::vector< tagged_lemma > > temp1 ;
    std::vector< std::vector< tagged_lemma > > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Analyses_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Analyses_size. "
          "Expected an array of " "std::vector< tagged_lemma >");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        std::vector< tagged_lemma >* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Analyses_size. "
              "Expected an array of " "std::vector< tagged_lemma >");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Analyses_size. "
          "Expected an array of " "std::vector< tagged_lemma >");
      }
    }
    result = (unsigned int)((std::vector< std::vector< tagged_lemma > > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_empty) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    std::vector< std::vector< tagged_lemma > > temp1 ;
    std::vector< std::vector< tagged_lemma > > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Analyses_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of Analyses_empty. "
          "Expected an array of " "std::vector< tagged_lemma >");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        std::vector< tagged_lemma >* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "Analyses_empty. "
              "Expected an array of " "std::vector< tagged_lemma >");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of Analyses_empty. "
          "Expected an array of " "std::vector< tagged_lemma >");
      }
    }
    result = (bool)((std::vector< std::vector< tagged_lemma > > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_clear) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Analyses_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Analyses_clear" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_push) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    std::vector< tagged_lemma > *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    std::vector< tagged_lemma > temp2 ;
    std::vector< tagged_lemma > *v2 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Analyses_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Analyses_push" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    {
      if (SWIG_ConvertPtr(ST(1),(void **) &v2, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg2 = v2;
      } else if (SvROK(ST(1))) {
        AV *av = (AV *)SvRV(ST(1));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 2 of Analyses_push. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp2.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 2 of "
              "Analyses_push. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg2 = &temp2;
      } else {
        SWIG_croak("Type error in argument 2 of Analyses_push. "
          "Expected an array of " "tagged_lemma");
      }
    }
    (arg1)->push_back((std::vector< tagged_lemma > const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_pop) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma > result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Analyses_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Analyses_pop" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    try {
      result = std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    {
      size_t len = (&result)->size();
      SV **svs = new SV*[len];
      for (size_t i=0; i<len; i++) {
        tagged_lemma* ptr = new tagged_lemma(result[i]);
        svs[i] = sv_newmortal();
        SWIG_MakePtr(svs[i], (void*) ptr, 
          SWIGTYPE_p_tagged_lemma, SWIG_SHADOW|0);
      }
      AV *myav = av_make(len, svs);
      delete[] svs;
      ST(argvi) = newRV_noinc((SV*) myav);
      sv_2mortal(ST(argvi));
      argvi++;
    }
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_get) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Analyses_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Analyses_get" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Analyses_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (std::vector< tagged_lemma > *) &std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_t, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Analyses_set) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    int arg2 ;
    std::vector< tagged_lemma > *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    std::vector< tagged_lemma > temp3 ;
    std::vector< tagged_lemma > *v3 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Analyses_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Analyses_set" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Analyses_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    {
      if (SWIG_ConvertPtr(ST(2),(void **) &v3, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_t,1) != -1) {
        arg3 = v3;
      } else if (SvROK(ST(2))) {
        AV *av = (AV *)SvRV(ST(2));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 3 of Analyses_set. "
          "Expected an array of " "tagged_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma,0) != -1) {
            temp3.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 3 of "
              "Analyses_set. "
              "Expected an array of " "tagged_lemma");
          }
        }
        arg3 = &temp3;
      } else {
        SWIG_croak("Type error in argument 3 of Analyses_set. "
          "Expected an array of " "tagged_lemma");
      }
    }
    try {
      std_vector_Sl_std_vector_Sl_tagged_lemma_Sg__Sg__set(arg1,arg2,(std::vector< tagged_lemma > const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Analyses) {
  {
    std::vector< std::vector< tagged_lemma > > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Analyses(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Analyses" "', argument " "1"" of type '" "std::vector< std::vector< tagged_lemma > > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< std::vector< tagged_lemma > > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmaForms_lemma_set) {
  {
    tagged_lemma_forms *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmaForms_lemma_set(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma_forms, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmaForms_lemma_set" "', argument " "1"" of type '" "tagged_lemma_forms *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma_forms * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemmaForms_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemmaForms_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->lemma = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmaForms_lemma_get) {
  {
    tagged_lemma_forms *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmaForms_lemma_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma_forms, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmaForms_lemma_get" "', argument " "1"" of type '" "tagged_lemma_forms *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma_forms * >(argp1);
    result = (std::string *) & ((arg1)->lemma);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmaForms_forms_set) {
  {
    tagged_lemma_forms *arg1 = 0 ;
    std::vector< tagged_form > *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmaForms_forms_set(self,forms);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma_forms, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmaForms_forms_set" "', argument " "1"" of type '" "tagged_lemma_forms *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma_forms * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2,SWIGTYPE_p_std__vectorT_tagged_form_t, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemmaForms_forms_set" "', argument " "2"" of type '" "std::vector< tagged_form > *""'"); 
    }
    arg2 = reinterpret_cast< std::vector< tagged_form > * >(argp2);
    if (arg1) (arg1)->forms = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmaForms_forms_get) {
  {
    tagged_lemma_forms *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::vector< tagged_form > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmaForms_forms_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma_forms, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmaForms_forms_get" "', argument " "1"" of type '" "tagged_lemma_forms *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma_forms * >(argp1);
    result = (std::vector< tagged_form > *)& ((arg1)->forms);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_form_t, 0 | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmaForms) {
  {
    int argvi = 0;
    tagged_lemma_forms *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedLemmaForms();");
    }
    result = (tagged_lemma_forms *)new tagged_lemma_forms();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_lemma_forms, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedLemmaForms) {
  {
    tagged_lemma_forms *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedLemmaForms(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagged_lemma_forms, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedLemmaForms" "', argument " "1"" of type '" "tagged_lemma_forms *""'"); 
    }
    arg1 = reinterpret_cast< tagged_lemma_forms * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmasForms__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma_forms > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedLemmasForms(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedLemmasForms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< tagged_lemma_forms > *)new std::vector< tagged_lemma_forms >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmasForms__SWIG_1) {
  {
    int argvi = 0;
    std::vector< tagged_lemma_forms > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TaggedLemmasForms();");
    }
    result = (std::vector< tagged_lemma_forms > *)new std::vector< tagged_lemma_forms >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmasForms__SWIG_2) {
  {
    unsigned int arg1 ;
    tagged_lemma_forms *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    std::vector< tagged_lemma_forms > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_TaggedLemmasForms(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TaggedLemmasForms" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma_forms,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_TaggedLemmasForms" "', argument " "2"" of type '" "tagged_lemma_forms const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "new_TaggedLemmasForms" "', argument " "2"" of type '" "tagged_lemma_forms const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma_forms * >(argp2);
    result = (std::vector< tagged_lemma_forms > *)new std::vector< tagged_lemma_forms >(arg1,(tagged_lemma_forms const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmasForms__SWIG_3) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    std::vector< tagged_lemma_forms > temp1 ;
    std::vector< tagged_lemma_forms > *v1 ;
    int argvi = 0;
    std::vector< tagged_lemma_forms > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TaggedLemmasForms(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_TaggedLemmasForms. "
          "Expected an array of " "tagged_lemma_forms");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma_forms* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma_forms,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_TaggedLemmasForms. "
              "Expected an array of " "tagged_lemma_forms");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_TaggedLemmasForms. "
          "Expected an array of " "tagged_lemma_forms");
      }
    }
    result = (std::vector< tagged_lemma_forms > *)new std::vector< tagged_lemma_forms >((std::vector< tagged_lemma_forms > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TaggedLemmasForms) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< tagged_lemma_forms >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  tagged_lemma_forms* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_tagged_lemma_forms,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_tagged_lemma_forms, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmasForms__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmasForms__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmasForms__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TaggedLemmasForms__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_TaggedLemmasForms'");
  XSRETURN(0);
}


XS(_wrap_TaggedLemmasForms_size) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    std::vector< tagged_lemma_forms > temp1 ;
    std::vector< tagged_lemma_forms > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmasForms_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedLemmasForms_size. "
          "Expected an array of " "tagged_lemma_forms");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma_forms* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma_forms,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedLemmasForms_size. "
              "Expected an array of " "tagged_lemma_forms");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedLemmasForms_size. "
          "Expected an array of " "tagged_lemma_forms");
      }
    }
    result = (unsigned int)((std::vector< tagged_lemma_forms > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_empty) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    std::vector< tagged_lemma_forms > temp1 ;
    std::vector< tagged_lemma_forms > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmasForms_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TaggedLemmasForms_empty. "
          "Expected an array of " "tagged_lemma_forms");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        tagged_lemma_forms* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_tagged_lemma_forms,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TaggedLemmasForms_empty. "
              "Expected an array of " "tagged_lemma_forms");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TaggedLemmasForms_empty. "
          "Expected an array of " "tagged_lemma_forms");
      }
    }
    result = (bool)((std::vector< tagged_lemma_forms > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_clear) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmasForms_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmasForms_clear" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_push) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    tagged_lemma_forms *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmasForms_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmasForms_push" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma_forms,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TaggedLemmasForms_push" "', argument " "2"" of type '" "tagged_lemma_forms const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemmasForms_push" "', argument " "2"" of type '" "tagged_lemma_forms const &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma_forms * >(argp2);
    (arg1)->push_back((tagged_lemma_forms const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_pop) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tagged_lemma_forms result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TaggedLemmasForms_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmasForms_pop" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    try {
      result = std_vector_Sl_tagged_lemma_forms_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj((new tagged_lemma_forms(result)), SWIGTYPE_p_tagged_lemma_forms, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_get) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    tagged_lemma_forms *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TaggedLemmasForms_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmasForms_get" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedLemmasForms_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (tagged_lemma_forms *) &std_vector_Sl_tagged_lemma_forms_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagged_lemma_forms, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TaggedLemmasForms_set) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    int arg2 ;
    tagged_lemma_forms *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: TaggedLemmasForms_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TaggedLemmasForms_set" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TaggedLemmasForms_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_tagged_lemma_forms,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "TaggedLemmasForms_set" "', argument " "3"" of type '" "tagged_lemma_forms const &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TaggedLemmasForms_set" "', argument " "3"" of type '" "tagged_lemma_forms const &""'"); 
    }
    arg3 = reinterpret_cast< tagged_lemma_forms * >(argp3);
    try {
      std_vector_Sl_tagged_lemma_forms_Sg__set(arg1,arg2,(tagged_lemma_forms const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TaggedLemmasForms) {
  {
    std::vector< tagged_lemma_forms > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TaggedLemmasForms(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TaggedLemmasForms" "', argument " "1"" of type '" "std::vector< tagged_lemma_forms > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRange_start_set) {
  {
    token_range *arg1 = 0 ;
    size_t arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    size_t val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TokenRange_start_set(self,start);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_token_range, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRange_start_set" "', argument " "1"" of type '" "token_range *""'"); 
    }
    arg1 = reinterpret_cast< token_range * >(argp1);
    ecode2 = SWIG_AsVal_size_t SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TokenRange_start_set" "', argument " "2"" of type '" "size_t""'");
    } 
    arg2 = static_cast< size_t >(val2);
    if (arg1) (arg1)->start = arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRange_start_get) {
  {
    token_range *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    size_t result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRange_start_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_token_range, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRange_start_get" "', argument " "1"" of type '" "token_range *""'"); 
    }
    arg1 = reinterpret_cast< token_range * >(argp1);
    result =  ((arg1)->start);
    ST(argvi) = SWIG_From_size_t  SWIG_PERL_CALL_ARGS_1(static_cast< size_t >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRange_length_set) {
  {
    token_range *arg1 = 0 ;
    size_t arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    size_t val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TokenRange_length_set(self,length);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_token_range, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRange_length_set" "', argument " "1"" of type '" "token_range *""'"); 
    }
    arg1 = reinterpret_cast< token_range * >(argp1);
    ecode2 = SWIG_AsVal_size_t SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TokenRange_length_set" "', argument " "2"" of type '" "size_t""'");
    } 
    arg2 = static_cast< size_t >(val2);
    if (arg1) (arg1)->length = arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRange_length_get) {
  {
    token_range *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    size_t result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRange_length_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_token_range, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRange_length_get" "', argument " "1"" of type '" "token_range *""'"); 
    }
    arg1 = reinterpret_cast< token_range * >(argp1);
    result =  ((arg1)->length);
    ST(argvi) = SWIG_From_size_t  SWIG_PERL_CALL_ARGS_1(static_cast< size_t >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRange) {
  {
    int argvi = 0;
    token_range *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TokenRange();");
    }
    result = (token_range *)new token_range();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_token_range, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TokenRange) {
  {
    token_range *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TokenRange(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_token_range, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TokenRange" "', argument " "1"" of type '" "token_range *""'"); 
    }
    arg1 = reinterpret_cast< token_range * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRanges__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< token_range > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TokenRanges(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TokenRanges" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< token_range > *)new std::vector< token_range >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_token_range_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRanges__SWIG_1) {
  {
    int argvi = 0;
    std::vector< token_range > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_TokenRanges();");
    }
    result = (std::vector< token_range > *)new std::vector< token_range >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_token_range_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRanges__SWIG_2) {
  {
    unsigned int arg1 ;
    token_range *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    std::vector< token_range > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_TokenRanges(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_TokenRanges" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_token_range,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_TokenRanges" "', argument " "2"" of type '" "token_range const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "new_TokenRanges" "', argument " "2"" of type '" "token_range const &""'"); 
    }
    arg2 = reinterpret_cast< token_range * >(argp2);
    result = (std::vector< token_range > *)new std::vector< token_range >(arg1,(token_range const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_token_range_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRanges__SWIG_3) {
  {
    std::vector< token_range > *arg1 = 0 ;
    std::vector< token_range > temp1 ;
    std::vector< token_range > *v1 ;
    int argvi = 0;
    std::vector< token_range > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_TokenRanges(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_token_range_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_TokenRanges. "
          "Expected an array of " "token_range");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        token_range* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_token_range,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_TokenRanges. "
              "Expected an array of " "token_range");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_TokenRanges. "
          "Expected an array of " "token_range");
      }
    }
    result = (std::vector< token_range > *)new std::vector< token_range >((std::vector< token_range > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_token_range_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_TokenRanges) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< token_range >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_token_range_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  token_range* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_token_range,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_token_range, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TokenRanges__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TokenRanges__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TokenRanges__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_TokenRanges__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_TokenRanges'");
  XSRETURN(0);
}


XS(_wrap_TokenRanges_size) {
  {
    std::vector< token_range > *arg1 = 0 ;
    std::vector< token_range > temp1 ;
    std::vector< token_range > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRanges_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_token_range_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TokenRanges_size. "
          "Expected an array of " "token_range");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        token_range* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_token_range,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TokenRanges_size. "
              "Expected an array of " "token_range");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TokenRanges_size. "
          "Expected an array of " "token_range");
      }
    }
    result = (unsigned int)((std::vector< token_range > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_empty) {
  {
    std::vector< token_range > *arg1 = 0 ;
    std::vector< token_range > temp1 ;
    std::vector< token_range > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRanges_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_token_range_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of TokenRanges_empty. "
          "Expected an array of " "token_range");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        token_range* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_token_range,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "TokenRanges_empty. "
              "Expected an array of " "token_range");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of TokenRanges_empty. "
          "Expected an array of " "token_range");
      }
    }
    result = (bool)((std::vector< token_range > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_clear) {
  {
    std::vector< token_range > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRanges_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRanges_clear" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_push) {
  {
    std::vector< token_range > *arg1 = 0 ;
    token_range *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TokenRanges_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRanges_push" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_token_range,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TokenRanges_push" "', argument " "2"" of type '" "token_range const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TokenRanges_push" "', argument " "2"" of type '" "token_range const &""'"); 
    }
    arg2 = reinterpret_cast< token_range * >(argp2);
    (arg1)->push_back((token_range const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_pop) {
  {
    std::vector< token_range > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    token_range result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TokenRanges_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRanges_pop" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    try {
      result = std_vector_Sl_token_range_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj((new token_range(result)), SWIGTYPE_p_token_range, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_get) {
  {
    std::vector< token_range > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    token_range *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TokenRanges_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRanges_get" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TokenRanges_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (token_range *) &std_vector_Sl_token_range_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_token_range, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TokenRanges_set) {
  {
    std::vector< token_range > *arg1 = 0 ;
    int arg2 ;
    token_range *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: TokenRanges_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TokenRanges_set" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "TokenRanges_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_token_range,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "TokenRanges_set" "', argument " "3"" of type '" "token_range const &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TokenRanges_set" "', argument " "3"" of type '" "token_range const &""'"); 
    }
    arg3 = reinterpret_cast< token_range * >(argp3);
    try {
      std_vector_Sl_token_range_Sg__set(arg1,arg2,(token_range const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TokenRanges) {
  {
    std::vector< token_range > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TokenRanges(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_token_range_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TokenRanges" "', argument " "1"" of type '" "std::vector< token_range > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< token_range > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemma_lemma_set) {
  {
    derivated_lemma *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivatedLemma_lemma_set(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivated_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemma_lemma_set" "', argument " "1"" of type '" "derivated_lemma *""'"); 
    }
    arg1 = reinterpret_cast< derivated_lemma * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivatedLemma_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivatedLemma_lemma_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->lemma = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemma_lemma_get) {
  {
    derivated_lemma *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivatedLemma_lemma_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivated_lemma, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemma_lemma_get" "', argument " "1"" of type '" "derivated_lemma *""'"); 
    }
    arg1 = reinterpret_cast< derivated_lemma * >(argp1);
    result = (std::string *) & ((arg1)->lemma);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemma) {
  {
    int argvi = 0;
    derivated_lemma *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_DerivatedLemma();");
    }
    result = (derivated_lemma *)new derivated_lemma();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivated_lemma, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_DerivatedLemma) {
  {
    derivated_lemma *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_DerivatedLemma(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivated_lemma, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DerivatedLemma" "', argument " "1"" of type '" "derivated_lemma *""'"); 
    }
    arg1 = reinterpret_cast< derivated_lemma * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemmas__SWIG_0) {
  {
    unsigned int arg1 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    int argvi = 0;
    std::vector< derivated_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_DerivatedLemmas(size);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_DerivatedLemmas" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    result = (std::vector< derivated_lemma > *)new std::vector< derivated_lemma >(arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_derivated_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemmas__SWIG_1) {
  {
    int argvi = 0;
    std::vector< derivated_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_DerivatedLemmas();");
    }
    result = (std::vector< derivated_lemma > *)new std::vector< derivated_lemma >();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_derivated_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemmas__SWIG_2) {
  {
    unsigned int arg1 ;
    derivated_lemma *arg2 = 0 ;
    unsigned int val1 ;
    int ecode1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    std::vector< derivated_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: new_DerivatedLemmas(size,value);");
    }
    ecode1 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), &val1);
    if (!SWIG_IsOK(ecode1)) {
      SWIG_exception_fail(SWIG_ArgError(ecode1), "in method '" "new_DerivatedLemmas" "', argument " "1"" of type '" "unsigned int""'");
    } 
    arg1 = static_cast< unsigned int >(val1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_derivated_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "new_DerivatedLemmas" "', argument " "2"" of type '" "derivated_lemma const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "new_DerivatedLemmas" "', argument " "2"" of type '" "derivated_lemma const &""'"); 
    }
    arg2 = reinterpret_cast< derivated_lemma * >(argp2);
    result = (std::vector< derivated_lemma > *)new std::vector< derivated_lemma >(arg1,(derivated_lemma const &)*arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_derivated_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemmas__SWIG_3) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    std::vector< derivated_lemma > temp1 ;
    std::vector< derivated_lemma > *v1 ;
    int argvi = 0;
    std::vector< derivated_lemma > *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: new_DerivatedLemmas(other);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_derivated_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of new_DerivatedLemmas. "
          "Expected an array of " "derivated_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        derivated_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_derivated_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "new_DerivatedLemmas. "
              "Expected an array of " "derivated_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of new_DerivatedLemmas. "
          "Expected an array of " "derivated_lemma");
      }
    }
    result = (std::vector< derivated_lemma > *)new std::vector< derivated_lemma >((std::vector< derivated_lemma > const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_std__vectorT_derivated_lemma_t, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_new_DerivatedLemmas) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 0) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
    if (items == 1) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          {
            /* wrapped vector? */
            std::vector< derivated_lemma >* v;
            if (SWIG_ConvertPtr(ST(0),(void **) &v, 
                SWIGTYPE_p_std__vectorT_derivated_lemma_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(0))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(0));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  derivated_lemma* obj;
                  SV **tv = av_fetch(av, 0, 0);
                  if (SWIG_ConvertPtr(*tv, (void **)&obj, 
                      SWIGTYPE_p_derivated_lemma,0) != -1)
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_3;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 3;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_3:
    
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        {
          int res = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(0), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_derivated_lemma, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_4;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 4;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_4:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_DerivatedLemmas__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_DerivatedLemmas__SWIG_0); return;
    case 3:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_DerivatedLemmas__SWIG_3); return;
    case 4:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_new_DerivatedLemmas__SWIG_2); return;
    }
  }
  
  croak("No matching function for overloaded 'new_DerivatedLemmas'");
  XSRETURN(0);
}


XS(_wrap_DerivatedLemmas_size) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    std::vector< derivated_lemma > temp1 ;
    std::vector< derivated_lemma > *v1 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivatedLemmas_size(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_derivated_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of DerivatedLemmas_size. "
          "Expected an array of " "derivated_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        derivated_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_derivated_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "DerivatedLemmas_size. "
              "Expected an array of " "derivated_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of DerivatedLemmas_size. "
          "Expected an array of " "derivated_lemma");
      }
    }
    result = (unsigned int)((std::vector< derivated_lemma > const *)arg1)->size();
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_empty) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    std::vector< derivated_lemma > temp1 ;
    std::vector< derivated_lemma > *v1 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivatedLemmas_empty(self);");
    }
    {
      if (SWIG_ConvertPtr(ST(0),(void **) &v1, 
          SWIGTYPE_p_std__vectorT_derivated_lemma_t,1) != -1) {
        arg1 = v1;
      } else if (SvROK(ST(0))) {
        AV *av = (AV *)SvRV(ST(0));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 1 of DerivatedLemmas_empty. "
          "Expected an array of " "derivated_lemma");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        derivated_lemma* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_derivated_lemma,0) != -1) {
            temp1.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 1 of "
              "DerivatedLemmas_empty. "
              "Expected an array of " "derivated_lemma");
          }
        }
        arg1 = &temp1;
      } else {
        SWIG_croak("Type error in argument 1 of DerivatedLemmas_empty. "
          "Expected an array of " "derivated_lemma");
      }
    }
    result = (bool)((std::vector< derivated_lemma > const *)arg1)->empty();
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_clear) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivatedLemmas_clear(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemmas_clear" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    (arg1)->clear();
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_push) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    derivated_lemma *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivatedLemmas_push(self,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemmas_push" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_derivated_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivatedLemmas_push" "', argument " "2"" of type '" "derivated_lemma const &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivatedLemmas_push" "', argument " "2"" of type '" "derivated_lemma const &""'"); 
    }
    arg2 = reinterpret_cast< derivated_lemma * >(argp2);
    (arg1)->push_back((derivated_lemma const &)*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_pop) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    derivated_lemma result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivatedLemmas_pop(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemmas_pop" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    try {
      result = std_vector_Sl_derivated_lemma_Sg__pop(arg1);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj((new derivated_lemma(result)), SWIGTYPE_p_derivated_lemma, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_get) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    derivated_lemma *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivatedLemmas_get(self,i);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemmas_get" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DerivatedLemmas_get" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    try {
      result = (derivated_lemma *) &std_vector_Sl_derivated_lemma_Sg__get(arg1,arg2);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivated_lemma, 0 | SWIG_SHADOW); argvi++ ;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivatedLemmas_set) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    int arg2 ;
    derivated_lemma *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int val2 ;
    int ecode2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: DerivatedLemmas_set(self,i,x);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivatedLemmas_set" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    ecode2 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "DerivatedLemmas_set" "', argument " "2"" of type '" "int""'");
    } 
    arg2 = static_cast< int >(val2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_derivated_lemma,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DerivatedLemmas_set" "', argument " "3"" of type '" "derivated_lemma const &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivatedLemmas_set" "', argument " "3"" of type '" "derivated_lemma const &""'"); 
    }
    arg3 = reinterpret_cast< derivated_lemma * >(argp3);
    try {
      std_vector_Sl_derivated_lemma_Sg__set(arg1,arg2,(derivated_lemma const &)*arg3);
    } catch(std::out_of_range &_e) {
      sv_setsv(get_sv("@", GV_ADD), SWIG_NewPointerObj((new std::out_of_range(static_cast< const std::out_of_range& >(_e))),SWIGTYPE_p_std__out_of_range,SWIG_POINTER_OWN)); SWIG_fail ;
    }
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_DerivatedLemmas) {
  {
    std::vector< derivated_lemma > *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_DerivatedLemmas(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_std__vectorT_derivated_lemma_t, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DerivatedLemmas" "', argument " "1"" of type '" "std::vector< derivated_lemma > *""'"); 
    }
    arg1 = reinterpret_cast< std::vector< derivated_lemma > * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_major_set) {
  {
    version *arg1 = 0 ;
    unsigned int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    unsigned int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Version_major_set(self,major);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_major_set" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    ecode2 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_major_set" "', argument " "2"" of type '" "unsigned int""'");
    } 
    arg2 = static_cast< unsigned int >(val2);
    if (arg1) (arg1)->major = arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_major_get) {
  {
    version *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Version_major_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_major_get" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    result = (unsigned int) ((arg1)->major);
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_minor_set) {
  {
    version *arg1 = 0 ;
    unsigned int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    unsigned int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Version_minor_set(self,minor);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_minor_set" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    ecode2 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_minor_set" "', argument " "2"" of type '" "unsigned int""'");
    } 
    arg2 = static_cast< unsigned int >(val2);
    if (arg1) (arg1)->minor = arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_minor_get) {
  {
    version *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Version_minor_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_minor_get" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    result = (unsigned int) ((arg1)->minor);
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_patch_set) {
  {
    version *arg1 = 0 ;
    unsigned int arg2 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    unsigned int val2 ;
    int ecode2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Version_patch_set(self,patch);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_patch_set" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    ecode2 = SWIG_AsVal_unsigned_SS_int SWIG_PERL_CALL_ARGS_2(ST(1), &val2);
    if (!SWIG_IsOK(ecode2)) {
      SWIG_exception_fail(SWIG_ArgError(ecode2), "in method '" "Version_patch_set" "', argument " "2"" of type '" "unsigned int""'");
    } 
    arg2 = static_cast< unsigned int >(val2);
    if (arg1) (arg1)->patch = arg2;
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_patch_get) {
  {
    version *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    unsigned int result;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Version_patch_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_patch_get" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    result = (unsigned int) ((arg1)->patch);
    ST(argvi) = SWIG_From_unsigned_SS_int  SWIG_PERL_CALL_ARGS_1(static_cast< unsigned int >(result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_prerelease_set) {
  {
    version *arg1 = 0 ;
    std::string *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 = SWIG_OLDOBJ ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Version_prerelease_set(self,prerelease);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_prerelease_set" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    {
      std::string *ptr = (std::string *)0;
      res2 = SWIG_AsPtr_std_string SWIG_PERL_CALL_ARGS_2(ST(1), &ptr);
      if (!SWIG_IsOK(res2)) {
        SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Version_prerelease_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      if (!ptr) {
        SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Version_prerelease_set" "', argument " "2"" of type '" "std::string const &""'"); 
      }
      arg2 = ptr;
    }
    if (arg1) (arg1)->prerelease = *arg2;
    ST(argvi) = &PL_sv_undef;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
    XSRETURN(argvi);
    fail:;
    
    if (SWIG_IsNewObj(res2)) delete arg2;
  }
  SWIG_croak_null();
}


XS(_wrap_Version_prerelease_get) {
  {
    version *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    std::string *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Version_prerelease_get(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Version_prerelease_get" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    result = (std::string *) & ((arg1)->prerelease);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(*result)); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Version_current) {
  {
    int argvi = 0;
    version result;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: Version_current();");
    }
    result = version::current();
    ST(argvi) = SWIG_NewPointerObj((new version(result)), SWIGTYPE_p_version, SWIG_POINTER_OWN | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_new_Version) {
  {
    int argvi = 0;
    version *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: new_Version();");
    }
    result = (version *)new version();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_version, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Version) {
  {
    version *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Version(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_version, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Version" "', argument " "1"" of type '" "version *""'"); 
    }
    arg1 = reinterpret_cast< version * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Tokenizer) {
  {
    tokenizer *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Tokenizer(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tokenizer, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Tokenizer" "', argument " "1"" of type '" "tokenizer *""'"); 
    }
    arg1 = reinterpret_cast< tokenizer * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_setText) {
  {
    tokenizer *arg1 = 0 ;
    char *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Tokenizer_setText(self,text);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tokenizer, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tokenizer_setText" "', argument " "1"" of type '" "tokenizer *""'"); 
    }
    arg1 = reinterpret_cast< tokenizer * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Tokenizer_setText" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    tokenizer_set_text(arg1,(char const *)arg2);
    ST(argvi) = &PL_sv_undef;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_nextSentence) {
  {
    tokenizer *arg1 = 0 ;
    std::vector< std::string > *arg2 = 0 ;
    std::vector< token_range > *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Tokenizer_nextSentence(self,forms,tokens);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tokenizer, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tokenizer_nextSentence" "', argument " "1"" of type '" "tokenizer *""'"); 
    }
    arg1 = reinterpret_cast< tokenizer * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2,SWIGTYPE_p_std__vectorT_std__string_t, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Tokenizer_nextSentence" "', argument " "2"" of type '" "std::vector< std::string > *""'"); 
    }
    arg2 = reinterpret_cast< std::vector< std::string > * >(argp2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3,SWIGTYPE_p_std__vectorT_token_range_t, 0 |  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Tokenizer_nextSentence" "', argument " "3"" of type '" "std::vector< token_range > *""'"); 
    }
    arg3 = reinterpret_cast< std::vector< token_range > * >(argp3);
    result = (bool)tokenizer_next_sentence(arg1,arg2,arg3);
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_newVerticalTokenizer) {
  {
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: Tokenizer_newVerticalTokenizer();");
    }
    result = (tokenizer *)tokenizer::new_vertical_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_newCzechTokenizer) {
  {
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: Tokenizer_newCzechTokenizer();");
    }
    result = (tokenizer *)tokenizer::new_czech_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_newEnglishTokenizer) {
  {
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: Tokenizer_newEnglishTokenizer();");
    }
    result = (tokenizer *)tokenizer::new_english_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_Tokenizer_newGenericTokenizer) {
  {
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: Tokenizer_newGenericTokenizer();");
    }
    result = (tokenizer *)tokenizer::new_generic_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Derivator) {
  {
    derivator *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Derivator(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Derivator" "', argument " "1"" of type '" "derivator *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Derivator_parent) {
  {
    derivator *arg1 = 0 ;
    char *arg2 = 0 ;
    derivated_lemma *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Derivator_parent(self,lemma,parent);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Derivator_parent" "', argument " "1"" of type '" "derivator const *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Derivator_parent" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_derivated_lemma,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Derivator_parent" "', argument " "3"" of type '" "derivated_lemma &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Derivator_parent" "', argument " "3"" of type '" "derivated_lemma &""'"); 
    }
    arg3 = reinterpret_cast< derivated_lemma * >(argp3);
    result = (bool)((derivator const *)arg1)->parent((char const *)arg2,*arg3);
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Derivator_children) {
  {
    derivator *arg1 = 0 ;
    char *arg2 = 0 ;
    std::vector< derivated_lemma > *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    bool result;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Derivator_children(self,lemma,children);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Derivator_children" "', argument " "1"" of type '" "derivator const *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Derivator_children" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_std__vectorT_derivated_lemma_t,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Derivator_children" "', argument " "3"" of type '" "std::vector< derivated_lemma > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Derivator_children" "', argument " "3"" of type '" "std::vector< derivated_lemma > &""'"); 
    }
    arg3 = reinterpret_cast< std::vector< derivated_lemma > * >(argp3);
    result = (bool)((derivator const *)arg1)->children((char const *)arg2,*arg3);
    ST(argvi) = SWIG_From_bool  SWIG_PERL_CALL_ARGS_1(static_cast< bool >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Morpho) {
  {
    morpho *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Morpho(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Morpho" "', argument " "1"" of type '" "morpho *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_load) {
  {
    char *arg1 = 0 ;
    int res1 ;
    char *buf1 = 0 ;
    int alloc1 = 0 ;
    int argvi = 0;
    morpho *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Morpho_load(fname);");
    }
    res1 = SWIG_AsCharPtrAndSize(ST(0), &buf1, NULL, &alloc1);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_load" "', argument " "1"" of type '" "char const *""'");
    }
    arg1 = reinterpret_cast< char * >(buf1);
    result = (morpho *)morpho::load((char const *)arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_morpho, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
    XSRETURN(argvi);
    fail:;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_analyze) {
  {
    morpho *arg1 = 0 ;
    char *arg2 = 0 ;
    morpho::guesser_mode arg3 ;
    std::vector< tagged_lemma > *arg4 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int val3 ;
    int ecode3 = 0 ;
    void *argp4 = 0 ;
    int res4 = 0 ;
    int argvi = 0;
    int result;
    dXSARGS;
    
    if ((items < 4) || (items > 4)) {
      SWIG_croak("Usage: Morpho_analyze(self,form,guesser,lemmas);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_analyze" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Morpho_analyze" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    ecode3 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(2), &val3);
    if (!SWIG_IsOK(ecode3)) {
      SWIG_exception_fail(SWIG_ArgError(ecode3), "in method '" "Morpho_analyze" "', argument " "3"" of type '" "morpho::guesser_mode""'");
    } 
    arg3 = static_cast< morpho::guesser_mode >(val3);
    res4 = SWIG_ConvertPtr(ST(3), &argp4, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Morpho_analyze" "', argument " "4"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp4) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Morpho_analyze" "', argument " "4"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg4 = reinterpret_cast< std::vector< tagged_lemma > * >(argp4);
    result = (int)((morpho const *)arg1)->analyze((char const *)arg2,arg3,*arg4);
    ST(argvi) = SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
    
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_generate) {
  {
    morpho *arg1 = 0 ;
    char *arg2 = 0 ;
    char *arg3 = 0 ;
    morpho::guesser_mode arg4 ;
    std::vector< tagged_lemma_forms > *arg5 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int res3 ;
    char *buf3 = 0 ;
    int alloc3 = 0 ;
    int val4 ;
    int ecode4 = 0 ;
    void *argp5 = 0 ;
    int res5 = 0 ;
    int argvi = 0;
    int result;
    dXSARGS;
    
    if ((items < 5) || (items > 5)) {
      SWIG_croak("Usage: Morpho_generate(self,lemma,tag_wildcard,guesser,forms);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_generate" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Morpho_generate" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    res3 = SWIG_AsCharPtrAndSize(ST(2), &buf3, NULL, &alloc3);
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Morpho_generate" "', argument " "3"" of type '" "char const *""'");
    }
    arg3 = reinterpret_cast< char * >(buf3);
    ecode4 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(3), &val4);
    if (!SWIG_IsOK(ecode4)) {
      SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Morpho_generate" "', argument " "4"" of type '" "morpho::guesser_mode""'");
    } 
    arg4 = static_cast< morpho::guesser_mode >(val4);
    res5 = SWIG_ConvertPtr(ST(4), &argp5, SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,  0 );
    if (!SWIG_IsOK(res5)) {
      SWIG_exception_fail(SWIG_ArgError(res5), "in method '" "Morpho_generate" "', argument " "5"" of type '" "std::vector< tagged_lemma_forms > &""'"); 
    }
    if (!argp5) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Morpho_generate" "', argument " "5"" of type '" "std::vector< tagged_lemma_forms > &""'"); 
    }
    arg5 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp5);
    result = (int)((morpho const *)arg1)->generate((char const *)arg2,(char const *)arg3,arg4,*arg5);
    ST(argvi) = SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    if (alloc3 == SWIG_NEWOBJ) delete[] buf3;
    
    
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    if (alloc3 == SWIG_NEWOBJ) delete[] buf3;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_rawLemma) {
  {
    morpho *arg1 = 0 ;
    char *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Morpho_rawLemma(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_rawLemma" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Morpho_rawLemma" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    result = morpho_raw_lemma((morpho const *)arg1,(char const *)arg2);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_lemmaId) {
  {
    morpho *arg1 = 0 ;
    char *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Morpho_lemmaId(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_lemmaId" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Morpho_lemmaId" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    result = morpho_lemma_id((morpho const *)arg1,(char const *)arg2);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_rawForm) {
  {
    morpho *arg1 = 0 ;
    char *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: Morpho_rawForm(self,form);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_rawForm" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "Morpho_rawForm" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    result = morpho_raw_form((morpho const *)arg1,(char const *)arg2);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_newTokenizer) {
  {
    morpho *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Morpho_newTokenizer(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_newTokenizer" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    result = (tokenizer *)((morpho const *)arg1)->new_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Morpho_getDerivator) {
  {
    morpho *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    derivator *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Morpho_getDerivator(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_morpho, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Morpho_getDerivator" "', argument " "1"" of type '" "morpho const *""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    result = (derivator *)((morpho const *)arg1)->get_derivator();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivator, 0 | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_Tagger) {
  {
    tagger *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_Tagger(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_Tagger" "', argument " "1"" of type '" "tagger *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_load) {
  {
    char *arg1 = 0 ;
    int res1 ;
    char *buf1 = 0 ;
    int alloc1 = 0 ;
    int argvi = 0;
    tagger *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Tagger_load(fname);");
    }
    res1 = SWIG_AsCharPtrAndSize(ST(0), &buf1, NULL, &alloc1);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_load" "', argument " "1"" of type '" "char const *""'");
    }
    arg1 = reinterpret_cast< char * >(buf1);
    result = (tagger *)tagger::load((char const *)arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagger, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
    XSRETURN(argvi);
    fail:;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_getMorpho) {
  {
    tagger *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    morpho *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Tagger_getMorpho(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_getMorpho" "', argument " "1"" of type '" "tagger const *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    result = (morpho *)((tagger const *)arg1)->get_morpho();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_morpho, 0 | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_tag__SWIG_0) {
  {
    tagger *arg1 = 0 ;
    std::vector< std::string > *arg2 = 0 ;
    std::vector< tagged_lemma > *arg3 = 0 ;
    int arg4 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    std::vector< std::string > temp2 ;
    std::vector< std::string > *v2 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int val4 ;
    int ecode4 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 4) || (items > 4)) {
      SWIG_croak("Usage: Tagger_tag(self,forms,tags,guesser);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_tag" "', argument " "1"" of type '" "tagger const *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    {
      if (SWIG_ConvertPtr(ST(1),(void **) &v2, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg2 = v2;
      } else if (SvROK(ST(1))) {
        AV *av = (AV *)SvRV(ST(1));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 2 of Tagger_tag. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp2.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 2 of "
              "Tagger_tag. "
              "Expected an array of ""std::string");
          }
        }
        arg2 = &temp2;
      } else {
        SWIG_croak("Type error in argument 2 of Tagger_tag. "
          "Expected an array of ""std::string");
      }
    }
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Tagger_tag" "', argument " "3"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Tagger_tag" "', argument " "3"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg3 = reinterpret_cast< std::vector< tagged_lemma > * >(argp3);
    ecode4 = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(3), &val4);
    if (!SWIG_IsOK(ecode4)) {
      SWIG_exception_fail(SWIG_ArgError(ecode4), "in method '" "Tagger_tag" "', argument " "4"" of type '" "int""'");
    } 
    arg4 = static_cast< int >(val4);
    tagger_tag__SWIG_0((tagger const *)arg1,(std::vector< std::string > const &)*arg2,*arg3,arg4);
    ST(argvi) = &PL_sv_undef;
    
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_tag__SWIG_1) {
  {
    tagger *arg1 = 0 ;
    std::vector< std::string > *arg2 = 0 ;
    std::vector< tagged_lemma > *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    std::vector< std::string > temp2 ;
    std::vector< std::string > *v2 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: Tagger_tag(self,forms,tags);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_tag" "', argument " "1"" of type '" "tagger const *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    {
      if (SWIG_ConvertPtr(ST(1),(void **) &v2, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg2 = v2;
      } else if (SvROK(ST(1))) {
        AV *av = (AV *)SvRV(ST(1));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 2 of Tagger_tag. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp2.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 2 of "
              "Tagger_tag. "
              "Expected an array of ""std::string");
          }
        }
        arg2 = &temp2;
      } else {
        SWIG_croak("Type error in argument 2 of Tagger_tag. "
          "Expected an array of ""std::string");
      }
    }
    res3 = SWIG_ConvertPtr(ST(2), &argp3, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "Tagger_tag" "', argument " "3"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp3) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Tagger_tag" "', argument " "3"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg3 = reinterpret_cast< std::vector< tagged_lemma > * >(argp3);
    tagger_tag__SWIG_0((tagger const *)arg1,(std::vector< std::string > const &)*arg2,*arg3);
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_tag) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 3) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_tagger, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        {
          {
            /* wrapped vector? */
            std::vector< std::string >* v;
            if (SWIG_ConvertPtr(ST(1),(void **) &v, 
                SWIGTYPE_p_std__vectorT_std__string_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(1))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(1));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  SV **tv = av_fetch(av, 0, 0);
                  if (SvPOK(*tv))
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(2), &vptr, SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_1:
    
    if (items == 4) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_tagger, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        {
          {
            /* wrapped vector? */
            std::vector< std::string >* v;
            if (SWIG_ConvertPtr(ST(1),(void **) &v, 
                SWIGTYPE_p_std__vectorT_std__string_t,0) != -1) {
              _v = 1;
            } else if (SvROK(ST(1))) {
              /* native sequence? */
              AV *av = (AV *)SvRV(ST(1));
              if (SvTYPE(av) == SVt_PVAV) {
                SSize_t len = av_len(av) + 1;
                if (len == 0) {
                  /* an empty sequence can be of any type */
                  _v = 1;
                } else {
                  /* check the first element only */
                  SV **tv = av_fetch(av, 0, 0);
                  if (SvPOK(*tv))
                  _v = 1;
                  else
                  _v = 0;
                }
              }
            } else {
              _v = 0;
            }
          }
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(2), &vptr, SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        {
          int res = SWIG_AsVal_int SWIG_PERL_CALL_ARGS_2(ST(3), NULL);
          _v = SWIG_CheckState(res);
        }
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_Tagger_tag__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_Tagger_tag__SWIG_0); return;
    }
  }
  
  croak("No matching function for overloaded 'Tagger_tag'");
  XSRETURN(0);
}


XS(_wrap_Tagger_tagAnalyzed) {
  {
    tagger *arg1 = 0 ;
    std::vector< std::string > *arg2 = 0 ;
    std::vector< std::vector< tagged_lemma > > *arg3 = 0 ;
    std::vector< int > *arg4 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    std::vector< std::string > temp2 ;
    std::vector< std::string > *v2 ;
    std::vector< std::vector< tagged_lemma > > temp3 ;
    std::vector< std::vector< tagged_lemma > > *v3 ;
    void *argp4 = 0 ;
    int res4 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 4) || (items > 4)) {
      SWIG_croak("Usage: Tagger_tagAnalyzed(self,forms,analyses,tags);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_tagAnalyzed" "', argument " "1"" of type '" "tagger const *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    {
      if (SWIG_ConvertPtr(ST(1),(void **) &v2, 
          SWIGTYPE_p_std__vectorT_std__string_t,1) != -1) {
        arg2 = v2;
      } else if (SvROK(ST(1))) {
        AV *av = (AV *)SvRV(ST(1));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 2 of Tagger_tagAnalyzed. "
          "Expected an array of ""std::string");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SvPOK(*tv)) {
            temp2.push_back((std::string)SwigSvToString(*tv));
          } else {
            SWIG_croak("Type error in argument 2 of "
              "Tagger_tagAnalyzed. "
              "Expected an array of ""std::string");
          }
        }
        arg2 = &temp2;
      } else {
        SWIG_croak("Type error in argument 2 of Tagger_tagAnalyzed. "
          "Expected an array of ""std::string");
      }
    }
    {
      if (SWIG_ConvertPtr(ST(2),(void **) &v3, 
          SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t,1) != -1) {
        arg3 = v3;
      } else if (SvROK(ST(2))) {
        AV *av = (AV *)SvRV(ST(2));
        if (SvTYPE(av) != SVt_PVAV)
        SWIG_croak("Type error in argument 3 of Tagger_tagAnalyzed. "
          "Expected an array of " "std::vector< tagged_lemma >");
        SV **tv;
        SSize_t len = av_len(av) + 1;
        std::vector< tagged_lemma >* obj;
        for (int i=0; i<len; i++) {
          tv = av_fetch(av, i, 0);
          if (SWIG_ConvertPtr(*tv, (void **)&obj, 
              SWIGTYPE_p_std__vectorT_tagged_lemma_t,0) != -1) {
            temp3.push_back(*obj);
          } else {
            SWIG_croak("Type error in argument 3 of "
              "Tagger_tagAnalyzed. "
              "Expected an array of " "std::vector< tagged_lemma >");
          }
        }
        arg3 = &temp3;
      } else {
        SWIG_croak("Type error in argument 3 of Tagger_tagAnalyzed. "
          "Expected an array of " "std::vector< tagged_lemma >");
      }
    }
    res4 = SWIG_ConvertPtr(ST(3), &argp4, SWIGTYPE_p_std__vectorT_int_t,  0 );
    if (!SWIG_IsOK(res4)) {
      SWIG_exception_fail(SWIG_ArgError(res4), "in method '" "Tagger_tagAnalyzed" "', argument " "4"" of type '" "std::vector< int > &""'"); 
    }
    if (!argp4) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "Tagger_tagAnalyzed" "', argument " "4"" of type '" "std::vector< int > &""'"); 
    }
    arg4 = reinterpret_cast< std::vector< int > * >(argp4);
    tagger_tagAnalyzed((tagger const *)arg1,(std::vector< std::string > const &)*arg2,(std::vector< std::vector< tagged_lemma > > const &)*arg3,*arg4);
    ST(argvi) = &PL_sv_undef;
    
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_Tagger_newTokenizer) {
  {
    tagger *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tokenizer *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: Tagger_newTokenizer(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagger, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "Tagger_newTokenizer" "', argument " "1"" of type '" "tagger const *""'"); 
    }
    arg1 = reinterpret_cast< tagger * >(argp1);
    result = (tokenizer *)((tagger const *)arg1)->new_tokenizer();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tokenizer, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_TagsetConverter) {
  {
    tagset_converter *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_TagsetConverter(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagset_converter, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_TagsetConverter" "', argument " "1"" of type '" "tagset_converter *""'"); 
    }
    arg1 = reinterpret_cast< tagset_converter * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_convert) {
  {
    tagset_converter *arg1 = 0 ;
    tagged_lemma *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TagsetConverter_convert(self,tagged_lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagset_converter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TagsetConverter_convert" "', argument " "1"" of type '" "tagset_converter const *""'"); 
    }
    arg1 = reinterpret_cast< tagset_converter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TagsetConverter_convert" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TagsetConverter_convert" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma * >(argp2);
    ((tagset_converter const *)arg1)->convert(*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_convertAnalyzed) {
  {
    tagset_converter *arg1 = 0 ;
    std::vector< tagged_lemma > *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TagsetConverter_convertAnalyzed(self,tagged_lemmas);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagset_converter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TagsetConverter_convertAnalyzed" "', argument " "1"" of type '" "tagset_converter const *""'"); 
    }
    arg1 = reinterpret_cast< tagset_converter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TagsetConverter_convertAnalyzed" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TagsetConverter_convertAnalyzed" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg2 = reinterpret_cast< std::vector< tagged_lemma > * >(argp2);
    ((tagset_converter const *)arg1)->convert_analyzed(*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_convertGenerated) {
  {
    tagset_converter *arg1 = 0 ;
    std::vector< tagged_lemma_forms > *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: TagsetConverter_convertGenerated(self,forms);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_tagset_converter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TagsetConverter_convertGenerated" "', argument " "1"" of type '" "tagset_converter const *""'"); 
    }
    arg1 = reinterpret_cast< tagset_converter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "TagsetConverter_convertGenerated" "', argument " "2"" of type '" "std::vector< tagged_lemma_forms > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TagsetConverter_convertGenerated" "', argument " "2"" of type '" "std::vector< tagged_lemma_forms > &""'"); 
    }
    arg2 = reinterpret_cast< std::vector< tagged_lemma_forms > * >(argp2);
    ((tagset_converter const *)arg1)->convert_generated(*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_newIdentityConverter) {
  {
    int argvi = 0;
    tagset_converter *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: TagsetConverter_newIdentityConverter();");
    }
    result = (tagset_converter *)tagset_converter::new_identity_converter();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagset_converter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_newPdtToConll2009Converter) {
  {
    int argvi = 0;
    tagset_converter *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: TagsetConverter_newPdtToConll2009Converter();");
    }
    result = (tagset_converter *)tagset_converter::new_pdt_to_conll2009_converter();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagset_converter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_newStripLemmaCommentConverter) {
  {
    morpho *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tagset_converter *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TagsetConverter_newStripLemmaCommentConverter(dictionary);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1, SWIGTYPE_p_morpho,  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TagsetConverter_newStripLemmaCommentConverter" "', argument " "1"" of type '" "morpho const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TagsetConverter_newStripLemmaCommentConverter" "', argument " "1"" of type '" "morpho const &""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    result = (tagset_converter *)tagset_converter::new_strip_lemma_comment_converter((morpho const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagset_converter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_TagsetConverter_newStripLemmaIdConverter) {
  {
    morpho *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    tagset_converter *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: TagsetConverter_newStripLemmaIdConverter(dictionary);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1, SWIGTYPE_p_morpho,  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "TagsetConverter_newStripLemmaIdConverter" "', argument " "1"" of type '" "morpho const &""'"); 
    }
    if (!argp1) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "TagsetConverter_newStripLemmaIdConverter" "', argument " "1"" of type '" "morpho const &""'"); 
    }
    arg1 = reinterpret_cast< morpho * >(argp1);
    result = (tagset_converter *)tagset_converter::new_strip_lemma_id_converter((morpho const &)*arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_tagset_converter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_delete_DerivationFormatter) {
  {
    derivation_formatter *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: delete_DerivationFormatter(self);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, SWIG_POINTER_DISOWN |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "delete_DerivationFormatter" "', argument " "1"" of type '" "derivation_formatter *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    delete arg1;
    ST(argvi) = &PL_sv_undef;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatDerivation) {
  {
    derivation_formatter *arg1 = 0 ;
    char *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int res2 ;
    char *buf2 = 0 ;
    int alloc2 = 0 ;
    int argvi = 0;
    std::string result;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivationFormatter_formatDerivation(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_formatDerivation" "', argument " "1"" of type '" "derivation_formatter const *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    res2 = SWIG_AsCharPtrAndSize(ST(1), &buf2, NULL, &alloc2);
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_formatDerivation" "', argument " "2"" of type '" "char const *""'");
    }
    arg2 = reinterpret_cast< char * >(buf2);
    result = derivation_formatter_format_derivation((derivation_formatter const *)arg1,(char const *)arg2);
    ST(argvi) = SWIG_From_std_string  SWIG_PERL_CALL_ARGS_1(static_cast< std::string >(result)); argvi++ ;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
    XSRETURN(argvi);
    fail:;
    
    if (alloc2 == SWIG_NEWOBJ) delete[] buf2;
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatTaggedLemma__SWIG_0) {
  {
    derivation_formatter *arg1 = 0 ;
    tagged_lemma *arg2 = 0 ;
    tagset_converter *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: DerivationFormatter_formatTaggedLemma(self,lemma,converter);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "1"" of type '" "derivation_formatter const *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma * >(argp2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3,SWIGTYPE_p_tagset_converter, 0 |  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "3"" of type '" "tagset_converter const *""'"); 
    }
    arg3 = reinterpret_cast< tagset_converter * >(argp3);
    ((derivation_formatter const *)arg1)->format_tagged_lemma(*arg2,(tagset_converter const *)arg3);
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatTaggedLemma__SWIG_1) {
  {
    derivation_formatter *arg1 = 0 ;
    tagged_lemma *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivationFormatter_formatTaggedLemma(self,lemma);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "1"" of type '" "derivation_formatter const *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_tagged_lemma,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivationFormatter_formatTaggedLemma" "', argument " "2"" of type '" "tagged_lemma &""'"); 
    }
    arg2 = reinterpret_cast< tagged_lemma * >(argp2);
    ((derivation_formatter const *)arg1)->format_tagged_lemma(*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatTaggedLemma) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_derivation_formatter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_tagged_lemma, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_1:
    
    if (items == 3) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_derivation_formatter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_tagged_lemma, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(2), &vptr, SWIGTYPE_p_tagset_converter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_DerivationFormatter_formatTaggedLemma__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_DerivationFormatter_formatTaggedLemma__SWIG_0); return;
    }
  }
  
  croak("No matching function for overloaded 'DerivationFormatter_formatTaggedLemma'");
  XSRETURN(0);
}


XS(_wrap_DerivationFormatter_formatTaggedLemmas__SWIG_0) {
  {
    derivation_formatter *arg1 = 0 ;
    std::vector< tagged_lemma > *arg2 = 0 ;
    tagset_converter *arg3 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    void *argp3 = 0 ;
    int res3 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 3) || (items > 3)) {
      SWIG_croak("Usage: DerivationFormatter_formatTaggedLemmas(self,lemmas,converter);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "1"" of type '" "derivation_formatter const *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg2 = reinterpret_cast< std::vector< tagged_lemma > * >(argp2);
    res3 = SWIG_ConvertPtr(ST(2), &argp3,SWIGTYPE_p_tagset_converter, 0 |  0 );
    if (!SWIG_IsOK(res3)) {
      SWIG_exception_fail(SWIG_ArgError(res3), "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "3"" of type '" "tagset_converter const *""'"); 
    }
    arg3 = reinterpret_cast< tagset_converter * >(argp3);
    ((derivation_formatter const *)arg1)->format_tagged_lemmas(*arg2,(tagset_converter const *)arg3);
    ST(argvi) = &PL_sv_undef;
    
    
    
    XSRETURN(argvi);
    fail:;
    
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatTaggedLemmas__SWIG_1) {
  {
    derivation_formatter *arg1 = 0 ;
    std::vector< tagged_lemma > *arg2 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivationFormatter_formatTaggedLemmas(self,lemmas);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivation_formatter, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "1"" of type '" "derivation_formatter const *""'"); 
    }
    arg1 = reinterpret_cast< derivation_formatter * >(argp1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2, SWIGTYPE_p_std__vectorT_tagged_lemma_t,  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    if (!argp2) {
      SWIG_exception_fail(SWIG_NullReferenceError, "invalid null reference " "in method '" "DerivationFormatter_formatTaggedLemmas" "', argument " "2"" of type '" "std::vector< tagged_lemma > &""'"); 
    }
    arg2 = reinterpret_cast< std::vector< tagged_lemma > * >(argp2);
    ((derivation_formatter const *)arg1)->format_tagged_lemmas(*arg2);
    ST(argvi) = &PL_sv_undef;
    
    
    XSRETURN(argvi);
    fail:;
    
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_formatTaggedLemmas) {
  dXSARGS;
  
  {
    unsigned long _index = 0;
    SWIG_TypeRank _rank = 0; 
    if (items == 2) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_derivation_formatter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_1;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 1;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_1:
    
    if (items == 3) {
      SWIG_TypeRank _ranki = 0;
      SWIG_TypeRank _rankm = 0;
      SWIG_TypeRank _pi = 1;
      int _v = 0;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(0), &vptr, SWIGTYPE_p_derivation_formatter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(1), &vptr, SWIGTYPE_p_std__vectorT_tagged_lemma_t, SWIG_POINTER_NO_NULL);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      {
        void *vptr = 0;
        int res = SWIG_ConvertPtr(ST(2), &vptr, SWIGTYPE_p_tagset_converter, 0);
        _v = SWIG_CheckState(res);
      }
      if (!_v) goto check_2;
      _ranki += _v*_pi;
      _rankm += _pi;
      _pi *= SWIG_MAXCASTRANK;
      if (!_index || (_ranki < _rank)) {
        _rank = _ranki; _index = 2;
        if (_rank == _rankm) goto dispatch;
      }
    }
  check_2:
    
  dispatch:
    switch(_index) {
    case 1:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_DerivationFormatter_formatTaggedLemmas__SWIG_1); return;
    case 2:
      PUSHMARK(MARK); SWIG_CALLXS(_wrap_DerivationFormatter_formatTaggedLemmas__SWIG_0); return;
    }
  }
  
  croak("No matching function for overloaded 'DerivationFormatter_formatTaggedLemmas'");
  XSRETURN(0);
}


XS(_wrap_DerivationFormatter_newNoneDerivationFormatter) {
  {
    int argvi = 0;
    derivation_formatter *result = 0 ;
    dXSARGS;
    
    if ((items < 0) || (items > 0)) {
      SWIG_croak("Usage: DerivationFormatter_newNoneDerivationFormatter();");
    }
    result = (derivation_formatter *)derivation_formatter::new_none_derivation_formatter();
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivation_formatter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    XSRETURN(argvi);
    fail:;
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_newRootDerivationFormatter) {
  {
    derivator *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    derivation_formatter *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivationFormatter_newRootDerivationFormatter(derinet);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_newRootDerivationFormatter" "', argument " "1"" of type '" "derivator const *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    result = (derivation_formatter *)derivation_formatter::new_root_derivation_formatter((derivator const *)arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivation_formatter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_newPathDerivationFormatter) {
  {
    derivator *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    derivation_formatter *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivationFormatter_newPathDerivationFormatter(derinet);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_newPathDerivationFormatter" "', argument " "1"" of type '" "derivator const *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    result = (derivation_formatter *)derivation_formatter::new_path_derivation_formatter((derivator const *)arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivation_formatter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_newTreeDerivationFormatter) {
  {
    derivator *arg1 = 0 ;
    void *argp1 = 0 ;
    int res1 = 0 ;
    int argvi = 0;
    derivation_formatter *result = 0 ;
    dXSARGS;
    
    if ((items < 1) || (items > 1)) {
      SWIG_croak("Usage: DerivationFormatter_newTreeDerivationFormatter(derinet);");
    }
    res1 = SWIG_ConvertPtr(ST(0), &argp1,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_newTreeDerivationFormatter" "', argument " "1"" of type '" "derivator const *""'"); 
    }
    arg1 = reinterpret_cast< derivator * >(argp1);
    result = (derivation_formatter *)derivation_formatter::new_tree_derivation_formatter((derivator const *)arg1);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivation_formatter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    
    XSRETURN(argvi);
    fail:;
    
  }
  SWIG_croak_null();
}


XS(_wrap_DerivationFormatter_newDerivationFormatter) {
  {
    char *arg1 = 0 ;
    derivator *arg2 = 0 ;
    int res1 ;
    char *buf1 = 0 ;
    int alloc1 = 0 ;
    void *argp2 = 0 ;
    int res2 = 0 ;
    int argvi = 0;
    derivation_formatter *result = 0 ;
    dXSARGS;
    
    if ((items < 2) || (items > 2)) {
      SWIG_croak("Usage: DerivationFormatter_newDerivationFormatter(name,derinet);");
    }
    res1 = SWIG_AsCharPtrAndSize(ST(0), &buf1, NULL, &alloc1);
    if (!SWIG_IsOK(res1)) {
      SWIG_exception_fail(SWIG_ArgError(res1), "in method '" "DerivationFormatter_newDerivationFormatter" "', argument " "1"" of type '" "char const *""'");
    }
    arg1 = reinterpret_cast< char * >(buf1);
    res2 = SWIG_ConvertPtr(ST(1), &argp2,SWIGTYPE_p_derivator, 0 |  0 );
    if (!SWIG_IsOK(res2)) {
      SWIG_exception_fail(SWIG_ArgError(res2), "in method '" "DerivationFormatter_newDerivationFormatter" "', argument " "2"" of type '" "derivator const *""'"); 
    }
    arg2 = reinterpret_cast< derivator * >(argp2);
    result = (derivation_formatter *)derivation_formatter::new_derivation_formatter((char const *)arg1,(derivator const *)arg2);
    ST(argvi) = SWIG_NewPointerObj(SWIG_as_voidptr(result), SWIGTYPE_p_derivation_formatter, SWIG_OWNER | SWIG_SHADOW); argvi++ ;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
    
    XSRETURN(argvi);
    fail:;
    if (alloc1 == SWIG_NEWOBJ) delete[] buf1;
    
  }
  SWIG_croak_null();
}



/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (BEGIN) -------- */

static swig_type_info _swigt__p_char = {"_p_char", "char *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_derivated_lemma = {"_p_derivated_lemma", "derivated_lemma *", 0, 0, (void*)"Ufal::MorphoDiTa::DerivatedLemma", 0};
static swig_type_info _swigt__p_derivation_formatter = {"_p_derivation_formatter", "derivation_formatter *", 0, 0, (void*)"Ufal::MorphoDiTa::DerivationFormatter", 0};
static swig_type_info _swigt__p_derivator = {"_p_derivator", "derivator *", 0, 0, (void*)"Ufal::MorphoDiTa::Derivator", 0};
static swig_type_info _swigt__p_difference_type = {"_p_difference_type", "difference_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_guesser_mode = {"_p_guesser_mode", "guesser_mode *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_morpho = {"_p_morpho", "morpho *", 0, 0, (void*)"Ufal::MorphoDiTa::Morpho", 0};
static swig_type_info _swigt__p_size_type = {"_p_size_type", "size_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__out_of_range = {"_p_std__out_of_range", "std::out_of_range *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_std__vectorT_derivated_lemma_t = {"_p_std__vectorT_derivated_lemma_t", "DerivatedLemmas *|std::vector< derivated_lemma > *", 0, 0, (void*)"Ufal::MorphoDiTa::DerivatedLemmas", 0};
static swig_type_info _swigt__p_std__vectorT_int_t = {"_p_std__vectorT_int_t", "Indices *|std::vector< int > *", 0, 0, (void*)"Ufal::MorphoDiTa::Indices", 0};
static swig_type_info _swigt__p_std__vectorT_std__string_t = {"_p_std__vectorT_std__string_t", "Forms *|std::vector< std::string > *", 0, 0, (void*)"Ufal::MorphoDiTa::Forms", 0};
static swig_type_info _swigt__p_std__vectorT_std__vectorT_tagged_lemma_t_t = {"_p_std__vectorT_std__vectorT_tagged_lemma_t_t", "Analyses *|std::vector< std::vector< tagged_lemma > > *", 0, 0, (void*)"Ufal::MorphoDiTa::Analyses", 0};
static swig_type_info _swigt__p_std__vectorT_tagged_form_t = {"_p_std__vectorT_tagged_form_t", "TaggedForms *|std::vector< tagged_form > *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedForms", 0};
static swig_type_info _swigt__p_std__vectorT_tagged_lemma_forms_t = {"_p_std__vectorT_tagged_lemma_forms_t", "TaggedLemmasForms *|std::vector< tagged_lemma_forms > *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedLemmasForms", 0};
static swig_type_info _swigt__p_std__vectorT_tagged_lemma_t = {"_p_std__vectorT_tagged_lemma_t", "TaggedLemmas *|std::vector< tagged_lemma > *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedLemmas", 0};
static swig_type_info _swigt__p_std__vectorT_token_range_t = {"_p_std__vectorT_token_range_t", "TokenTanges *|std::vector< token_range > *", 0, 0, (void*)"Ufal::MorphoDiTa::TokenRanges", 0};
static swig_type_info _swigt__p_tagged_form = {"_p_tagged_form", "tagged_form *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedForm", 0};
static swig_type_info _swigt__p_tagged_lemma = {"_p_tagged_lemma", "tagged_lemma *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedLemma", 0};
static swig_type_info _swigt__p_tagged_lemma_forms = {"_p_tagged_lemma_forms", "tagged_lemma_forms *", 0, 0, (void*)"Ufal::MorphoDiTa::TaggedLemmaForms", 0};
static swig_type_info _swigt__p_tagger = {"_p_tagger", "tagger *", 0, 0, (void*)"Ufal::MorphoDiTa::Tagger", 0};
static swig_type_info _swigt__p_tagset_converter = {"_p_tagset_converter", "tagset_converter *", 0, 0, (void*)"Ufal::MorphoDiTa::TagsetConverter", 0};
static swig_type_info _swigt__p_token_range = {"_p_token_range", "token_range *", 0, 0, (void*)"Ufal::MorphoDiTa::TokenRange", 0};
static swig_type_info _swigt__p_tokenizer = {"_p_tokenizer", "tokenizer *", 0, 0, (void*)"Ufal::MorphoDiTa::Tokenizer", 0};
static swig_type_info _swigt__p_value_type = {"_p_value_type", "value_type *", 0, 0, (void*)0, 0};
static swig_type_info _swigt__p_version = {"_p_version", "version *", 0, 0, (void*)"Ufal::MorphoDiTa::Version", 0};

static swig_type_info *swig_type_initial[] = {
  &_swigt__p_char,
  &_swigt__p_derivated_lemma,
  &_swigt__p_derivation_formatter,
  &_swigt__p_derivator,
  &_swigt__p_difference_type,
  &_swigt__p_guesser_mode,
  &_swigt__p_morpho,
  &_swigt__p_size_type,
  &_swigt__p_std__out_of_range,
  &_swigt__p_std__vectorT_derivated_lemma_t,
  &_swigt__p_std__vectorT_int_t,
  &_swigt__p_std__vectorT_std__string_t,
  &_swigt__p_std__vectorT_std__vectorT_tagged_lemma_t_t,
  &_swigt__p_std__vectorT_tagged_form_t,
  &_swigt__p_std__vectorT_tagged_lemma_forms_t,
  &_swigt__p_std__vectorT_tagged_lemma_t,
  &_swigt__p_std__vectorT_token_range_t,
  &_swigt__p_tagged_form,
  &_swigt__p_tagged_lemma,
  &_swigt__p_tagged_lemma_forms,
  &_swigt__p_tagger,
  &_swigt__p_tagset_converter,
  &_swigt__p_token_range,
  &_swigt__p_tokenizer,
  &_swigt__p_value_type,
  &_swigt__p_version,
};

static swig_cast_info _swigc__p_char[] = {  {&_swigt__p_char, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_derivated_lemma[] = {  {&_swigt__p_derivated_lemma, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_derivation_formatter[] = {  {&_swigt__p_derivation_formatter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_derivator[] = {  {&_swigt__p_derivator, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_difference_type[] = {  {&_swigt__p_difference_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_guesser_mode[] = {  {&_swigt__p_guesser_mode, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_morpho[] = {  {&_swigt__p_morpho, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_size_type[] = {  {&_swigt__p_size_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__out_of_range[] = {  {&_swigt__p_std__out_of_range, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_derivated_lemma_t[] = {  {&_swigt__p_std__vectorT_derivated_lemma_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_int_t[] = {  {&_swigt__p_std__vectorT_int_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_std__string_t[] = {  {&_swigt__p_std__vectorT_std__string_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_std__vectorT_tagged_lemma_t_t[] = {  {&_swigt__p_std__vectorT_std__vectorT_tagged_lemma_t_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_tagged_form_t[] = {  {&_swigt__p_std__vectorT_tagged_form_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_tagged_lemma_forms_t[] = {  {&_swigt__p_std__vectorT_tagged_lemma_forms_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_tagged_lemma_t[] = {  {&_swigt__p_std__vectorT_tagged_lemma_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_std__vectorT_token_range_t[] = {  {&_swigt__p_std__vectorT_token_range_t, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tagged_form[] = {  {&_swigt__p_tagged_form, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tagged_lemma[] = {  {&_swigt__p_tagged_lemma, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tagged_lemma_forms[] = {  {&_swigt__p_tagged_lemma_forms, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tagger[] = {  {&_swigt__p_tagger, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tagset_converter[] = {  {&_swigt__p_tagset_converter, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_token_range[] = {  {&_swigt__p_token_range, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_tokenizer[] = {  {&_swigt__p_tokenizer, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_value_type[] = {  {&_swigt__p_value_type, 0, 0, 0},{0, 0, 0, 0}};
static swig_cast_info _swigc__p_version[] = {  {&_swigt__p_version, 0, 0, 0},{0, 0, 0, 0}};

static swig_cast_info *swig_cast_initial[] = {
  _swigc__p_char,
  _swigc__p_derivated_lemma,
  _swigc__p_derivation_formatter,
  _swigc__p_derivator,
  _swigc__p_difference_type,
  _swigc__p_guesser_mode,
  _swigc__p_morpho,
  _swigc__p_size_type,
  _swigc__p_std__out_of_range,
  _swigc__p_std__vectorT_derivated_lemma_t,
  _swigc__p_std__vectorT_int_t,
  _swigc__p_std__vectorT_std__string_t,
  _swigc__p_std__vectorT_std__vectorT_tagged_lemma_t_t,
  _swigc__p_std__vectorT_tagged_form_t,
  _swigc__p_std__vectorT_tagged_lemma_forms_t,
  _swigc__p_std__vectorT_tagged_lemma_t,
  _swigc__p_std__vectorT_token_range_t,
  _swigc__p_tagged_form,
  _swigc__p_tagged_lemma,
  _swigc__p_tagged_lemma_forms,
  _swigc__p_tagger,
  _swigc__p_tagset_converter,
  _swigc__p_token_range,
  _swigc__p_tokenizer,
  _swigc__p_value_type,
  _swigc__p_version,
};


/* -------- TYPE CONVERSION AND EQUIVALENCE RULES (END) -------- */

static swig_constant_info swig_constants[] = {
{0,0,0,0,0,0}
};
#ifdef __cplusplus
}
#endif
static swig_variable_info swig_variables[] = {
{0,0,0,0}
};
static swig_command_info swig_commands[] = {
{"Ufal::MorphoDiTac::new_Indices", _wrap_new_Indices},
{"Ufal::MorphoDiTac::Indices_size", _wrap_Indices_size},
{"Ufal::MorphoDiTac::Indices_empty", _wrap_Indices_empty},
{"Ufal::MorphoDiTac::Indices_clear", _wrap_Indices_clear},
{"Ufal::MorphoDiTac::Indices_push", _wrap_Indices_push},
{"Ufal::MorphoDiTac::Indices_pop", _wrap_Indices_pop},
{"Ufal::MorphoDiTac::Indices_get", _wrap_Indices_get},
{"Ufal::MorphoDiTac::Indices_set", _wrap_Indices_set},
{"Ufal::MorphoDiTac::delete_Indices", _wrap_delete_Indices},
{"Ufal::MorphoDiTac::new_Forms", _wrap_new_Forms},
{"Ufal::MorphoDiTac::Forms_size", _wrap_Forms_size},
{"Ufal::MorphoDiTac::Forms_empty", _wrap_Forms_empty},
{"Ufal::MorphoDiTac::Forms_clear", _wrap_Forms_clear},
{"Ufal::MorphoDiTac::Forms_push", _wrap_Forms_push},
{"Ufal::MorphoDiTac::Forms_pop", _wrap_Forms_pop},
{"Ufal::MorphoDiTac::Forms_get", _wrap_Forms_get},
{"Ufal::MorphoDiTac::Forms_set", _wrap_Forms_set},
{"Ufal::MorphoDiTac::delete_Forms", _wrap_delete_Forms},
{"Ufal::MorphoDiTac::TaggedForm_form_set", _wrap_TaggedForm_form_set},
{"Ufal::MorphoDiTac::TaggedForm_form_get", _wrap_TaggedForm_form_get},
{"Ufal::MorphoDiTac::TaggedForm_tag_set", _wrap_TaggedForm_tag_set},
{"Ufal::MorphoDiTac::TaggedForm_tag_get", _wrap_TaggedForm_tag_get},
{"Ufal::MorphoDiTac::new_TaggedForm", _wrap_new_TaggedForm},
{"Ufal::MorphoDiTac::delete_TaggedForm", _wrap_delete_TaggedForm},
{"Ufal::MorphoDiTac::new_TaggedForms", _wrap_new_TaggedForms},
{"Ufal::MorphoDiTac::TaggedForms_size", _wrap_TaggedForms_size},
{"Ufal::MorphoDiTac::TaggedForms_empty", _wrap_TaggedForms_empty},
{"Ufal::MorphoDiTac::TaggedForms_clear", _wrap_TaggedForms_clear},
{"Ufal::MorphoDiTac::TaggedForms_push", _wrap_TaggedForms_push},
{"Ufal::MorphoDiTac::TaggedForms_pop", _wrap_TaggedForms_pop},
{"Ufal::MorphoDiTac::TaggedForms_get", _wrap_TaggedForms_get},
{"Ufal::MorphoDiTac::TaggedForms_set", _wrap_TaggedForms_set},
{"Ufal::MorphoDiTac::delete_TaggedForms", _wrap_delete_TaggedForms},
{"Ufal::MorphoDiTac::TaggedLemma_lemma_set", _wrap_TaggedLemma_lemma_set},
{"Ufal::MorphoDiTac::TaggedLemma_lemma_get", _wrap_TaggedLemma_lemma_get},
{"Ufal::MorphoDiTac::TaggedLemma_tag_set", _wrap_TaggedLemma_tag_set},
{"Ufal::MorphoDiTac::TaggedLemma_tag_get", _wrap_TaggedLemma_tag_get},
{"Ufal::MorphoDiTac::new_TaggedLemma", _wrap_new_TaggedLemma},
{"Ufal::MorphoDiTac::delete_TaggedLemma", _wrap_delete_TaggedLemma},
{"Ufal::MorphoDiTac::new_TaggedLemmas", _wrap_new_TaggedLemmas},
{"Ufal::MorphoDiTac::TaggedLemmas_size", _wrap_TaggedLemmas_size},
{"Ufal::MorphoDiTac::TaggedLemmas_empty", _wrap_TaggedLemmas_empty},
{"Ufal::MorphoDiTac::TaggedLemmas_clear", _wrap_TaggedLemmas_clear},
{"Ufal::MorphoDiTac::TaggedLemmas_push", _wrap_TaggedLemmas_push},
{"Ufal::MorphoDiTac::TaggedLemmas_pop", _wrap_TaggedLemmas_pop},
{"Ufal::MorphoDiTac::TaggedLemmas_get", _wrap_TaggedLemmas_get},
{"Ufal::MorphoDiTac::TaggedLemmas_set", _wrap_TaggedLemmas_set},
{"Ufal::MorphoDiTac::delete_TaggedLemmas", _wrap_delete_TaggedLemmas},
{"Ufal::MorphoDiTac::new_Analyses", _wrap_new_Analyses},
{"Ufal::MorphoDiTac::Analyses_size", _wrap_Analyses_size},
{"Ufal::MorphoDiTac::Analyses_empty", _wrap_Analyses_empty},
{"Ufal::MorphoDiTac::Analyses_clear", _wrap_Analyses_clear},
{"Ufal::MorphoDiTac::Analyses_push", _wrap_Analyses_push},
{"Ufal::MorphoDiTac::Analyses_pop", _wrap_Analyses_pop},
{"Ufal::MorphoDiTac::Analyses_get", _wrap_Analyses_get},
{"Ufal::MorphoDiTac::Analyses_set", _wrap_Analyses_set},
{"Ufal::MorphoDiTac::delete_Analyses", _wrap_delete_Analyses},
{"Ufal::MorphoDiTac::TaggedLemmaForms_lemma_set", _wrap_TaggedLemmaForms_lemma_set},
{"Ufal::MorphoDiTac::TaggedLemmaForms_lemma_get", _wrap_TaggedLemmaForms_lemma_get},
{"Ufal::MorphoDiTac::TaggedLemmaForms_forms_set", _wrap_TaggedLemmaForms_forms_set},
{"Ufal::MorphoDiTac::TaggedLemmaForms_forms_get", _wrap_TaggedLemmaForms_forms_get},
{"Ufal::MorphoDiTac::new_TaggedLemmaForms", _wrap_new_TaggedLemmaForms},
{"Ufal::MorphoDiTac::delete_TaggedLemmaForms", _wrap_delete_TaggedLemmaForms},
{"Ufal::MorphoDiTac::new_TaggedLemmasForms", _wrap_new_TaggedLemmasForms},
{"Ufal::MorphoDiTac::TaggedLemmasForms_size", _wrap_TaggedLemmasForms_size},
{"Ufal::MorphoDiTac::TaggedLemmasForms_empty", _wrap_TaggedLemmasForms_empty},
{"Ufal::MorphoDiTac::TaggedLemmasForms_clear", _wrap_TaggedLemmasForms_clear},
{"Ufal::MorphoDiTac::TaggedLemmasForms_push", _wrap_TaggedLemmasForms_push},
{"Ufal::MorphoDiTac::TaggedLemmasForms_pop", _wrap_TaggedLemmasForms_pop},
{"Ufal::MorphoDiTac::TaggedLemmasForms_get", _wrap_TaggedLemmasForms_get},
{"Ufal::MorphoDiTac::TaggedLemmasForms_set", _wrap_TaggedLemmasForms_set},
{"Ufal::MorphoDiTac::delete_TaggedLemmasForms", _wrap_delete_TaggedLemmasForms},
{"Ufal::MorphoDiTac::TokenRange_start_set", _wrap_TokenRange_start_set},
{"Ufal::MorphoDiTac::TokenRange_start_get", _wrap_TokenRange_start_get},
{"Ufal::MorphoDiTac::TokenRange_length_set", _wrap_TokenRange_length_set},
{"Ufal::MorphoDiTac::TokenRange_length_get", _wrap_TokenRange_length_get},
{"Ufal::MorphoDiTac::new_TokenRange", _wrap_new_TokenRange},
{"Ufal::MorphoDiTac::delete_TokenRange", _wrap_delete_TokenRange},
{"Ufal::MorphoDiTac::new_TokenRanges", _wrap_new_TokenRanges},
{"Ufal::MorphoDiTac::TokenRanges_size", _wrap_TokenRanges_size},
{"Ufal::MorphoDiTac::TokenRanges_empty", _wrap_TokenRanges_empty},
{"Ufal::MorphoDiTac::TokenRanges_clear", _wrap_TokenRanges_clear},
{"Ufal::MorphoDiTac::TokenRanges_push", _wrap_TokenRanges_push},
{"Ufal::MorphoDiTac::TokenRanges_pop", _wrap_TokenRanges_pop},
{"Ufal::MorphoDiTac::TokenRanges_get", _wrap_TokenRanges_get},
{"Ufal::MorphoDiTac::TokenRanges_set", _wrap_TokenRanges_set},
{"Ufal::MorphoDiTac::delete_TokenRanges", _wrap_delete_TokenRanges},
{"Ufal::MorphoDiTac::DerivatedLemma_lemma_set", _wrap_DerivatedLemma_lemma_set},
{"Ufal::MorphoDiTac::DerivatedLemma_lemma_get", _wrap_DerivatedLemma_lemma_get},
{"Ufal::MorphoDiTac::new_DerivatedLemma", _wrap_new_DerivatedLemma},
{"Ufal::MorphoDiTac::delete_DerivatedLemma", _wrap_delete_DerivatedLemma},
{"Ufal::MorphoDiTac::new_DerivatedLemmas", _wrap_new_DerivatedLemmas},
{"Ufal::MorphoDiTac::DerivatedLemmas_size", _wrap_DerivatedLemmas_size},
{"Ufal::MorphoDiTac::DerivatedLemmas_empty", _wrap_DerivatedLemmas_empty},
{"Ufal::MorphoDiTac::DerivatedLemmas_clear", _wrap_DerivatedLemmas_clear},
{"Ufal::MorphoDiTac::DerivatedLemmas_push", _wrap_DerivatedLemmas_push},
{"Ufal::MorphoDiTac::DerivatedLemmas_pop", _wrap_DerivatedLemmas_pop},
{"Ufal::MorphoDiTac::DerivatedLemmas_get", _wrap_DerivatedLemmas_get},
{"Ufal::MorphoDiTac::DerivatedLemmas_set", _wrap_DerivatedLemmas_set},
{"Ufal::MorphoDiTac::delete_DerivatedLemmas", _wrap_delete_DerivatedLemmas},
{"Ufal::MorphoDiTac::Version_major_set", _wrap_Version_major_set},
{"Ufal::MorphoDiTac::Version_major_get", _wrap_Version_major_get},
{"Ufal::MorphoDiTac::Version_minor_set", _wrap_Version_minor_set},
{"Ufal::MorphoDiTac::Version_minor_get", _wrap_Version_minor_get},
{"Ufal::MorphoDiTac::Version_patch_set", _wrap_Version_patch_set},
{"Ufal::MorphoDiTac::Version_patch_get", _wrap_Version_patch_get},
{"Ufal::MorphoDiTac::Version_prerelease_set", _wrap_Version_prerelease_set},
{"Ufal::MorphoDiTac::Version_prerelease_get", _wrap_Version_prerelease_get},
{"Ufal::MorphoDiTac::Version_current", _wrap_Version_current},
{"Ufal::MorphoDiTac::new_Version", _wrap_new_Version},
{"Ufal::MorphoDiTac::delete_Version", _wrap_delete_Version},
{"Ufal::MorphoDiTac::delete_Tokenizer", _wrap_delete_Tokenizer},
{"Ufal::MorphoDiTac::Tokenizer_setText", _wrap_Tokenizer_setText},
{"Ufal::MorphoDiTac::Tokenizer_nextSentence", _wrap_Tokenizer_nextSentence},
{"Ufal::MorphoDiTac::Tokenizer_newVerticalTokenizer", _wrap_Tokenizer_newVerticalTokenizer},
{"Ufal::MorphoDiTac::Tokenizer_newCzechTokenizer", _wrap_Tokenizer_newCzechTokenizer},
{"Ufal::MorphoDiTac::Tokenizer_newEnglishTokenizer", _wrap_Tokenizer_newEnglishTokenizer},
{"Ufal::MorphoDiTac::Tokenizer_newGenericTokenizer", _wrap_Tokenizer_newGenericTokenizer},
{"Ufal::MorphoDiTac::delete_Derivator", _wrap_delete_Derivator},
{"Ufal::MorphoDiTac::Derivator_parent", _wrap_Derivator_parent},
{"Ufal::MorphoDiTac::Derivator_children", _wrap_Derivator_children},
{"Ufal::MorphoDiTac::delete_Morpho", _wrap_delete_Morpho},
{"Ufal::MorphoDiTac::Morpho_load", _wrap_Morpho_load},
{"Ufal::MorphoDiTac::Morpho_analyze", _wrap_Morpho_analyze},
{"Ufal::MorphoDiTac::Morpho_generate", _wrap_Morpho_generate},
{"Ufal::MorphoDiTac::Morpho_rawLemma", _wrap_Morpho_rawLemma},
{"Ufal::MorphoDiTac::Morpho_lemmaId", _wrap_Morpho_lemmaId},
{"Ufal::MorphoDiTac::Morpho_rawForm", _wrap_Morpho_rawForm},
{"Ufal::MorphoDiTac::Morpho_newTokenizer", _wrap_Morpho_newTokenizer},
{"Ufal::MorphoDiTac::Morpho_getDerivator", _wrap_Morpho_getDerivator},
{"Ufal::MorphoDiTac::delete_Tagger", _wrap_delete_Tagger},
{"Ufal::MorphoDiTac::Tagger_load", _wrap_Tagger_load},
{"Ufal::MorphoDiTac::Tagger_getMorpho", _wrap_Tagger_getMorpho},
{"Ufal::MorphoDiTac::Tagger_tag", _wrap_Tagger_tag},
{"Ufal::MorphoDiTac::Tagger_tagAnalyzed", _wrap_Tagger_tagAnalyzed},
{"Ufal::MorphoDiTac::Tagger_newTokenizer", _wrap_Tagger_newTokenizer},
{"Ufal::MorphoDiTac::delete_TagsetConverter", _wrap_delete_TagsetConverter},
{"Ufal::MorphoDiTac::TagsetConverter_convert", _wrap_TagsetConverter_convert},
{"Ufal::MorphoDiTac::TagsetConverter_convertAnalyzed", _wrap_TagsetConverter_convertAnalyzed},
{"Ufal::MorphoDiTac::TagsetConverter_convertGenerated", _wrap_TagsetConverter_convertGenerated},
{"Ufal::MorphoDiTac::TagsetConverter_newIdentityConverter", _wrap_TagsetConverter_newIdentityConverter},
{"Ufal::MorphoDiTac::TagsetConverter_newPdtToConll2009Converter", _wrap_TagsetConverter_newPdtToConll2009Converter},
{"Ufal::MorphoDiTac::TagsetConverter_newStripLemmaCommentConverter", _wrap_TagsetConverter_newStripLemmaCommentConverter},
{"Ufal::MorphoDiTac::TagsetConverter_newStripLemmaIdConverter", _wrap_TagsetConverter_newStripLemmaIdConverter},
{"Ufal::MorphoDiTac::delete_DerivationFormatter", _wrap_delete_DerivationFormatter},
{"Ufal::MorphoDiTac::DerivationFormatter_formatDerivation", _wrap_DerivationFormatter_formatDerivation},
{"Ufal::MorphoDiTac::DerivationFormatter_formatTaggedLemma", _wrap_DerivationFormatter_formatTaggedLemma},
{"Ufal::MorphoDiTac::DerivationFormatter_formatTaggedLemmas", _wrap_DerivationFormatter_formatTaggedLemmas},
{"Ufal::MorphoDiTac::DerivationFormatter_newNoneDerivationFormatter", _wrap_DerivationFormatter_newNoneDerivationFormatter},
{"Ufal::MorphoDiTac::DerivationFormatter_newRootDerivationFormatter", _wrap_DerivationFormatter_newRootDerivationFormatter},
{"Ufal::MorphoDiTac::DerivationFormatter_newPathDerivationFormatter", _wrap_DerivationFormatter_newPathDerivationFormatter},
{"Ufal::MorphoDiTac::DerivationFormatter_newTreeDerivationFormatter", _wrap_DerivationFormatter_newTreeDerivationFormatter},
{"Ufal::MorphoDiTac::DerivationFormatter_newDerivationFormatter", _wrap_DerivationFormatter_newDerivationFormatter},
{0,0}
};
/* -----------------------------------------------------------------------------
 * Type initialization:
 * This problem is made tough by the requirement that no dynamic
 * memory is used. Also, since swig_type_info structures store pointers to
 * swig_cast_info structures and swig_cast_info structures store pointers back
 * to swig_type_info structures, we need some lookup code at initialization.
 * The idea is that swig generates all the structures that are needed.
 * The runtime then collects these partially filled structures.
 * The SWIG_InitializeModule function takes these initial arrays out of
 * swig_module, and does all the lookup, filling in the swig_module.types
 * array with the correct data and linking the correct swig_cast_info
 * structures together.
 *
 * The generated swig_type_info structures are assigned statically to an initial
 * array. We just loop through that array, and handle each type individually.
 * First we lookup if this type has been already loaded, and if so, use the
 * loaded structure instead of the generated one. Then we have to fill in the
 * cast dependencies. The cast data is initially stored in something like a
 * two-dimensional array. Each row corresponds to a type (there are the same
 * number of rows as there are in the swig_type_initial array). Each entry in
 * a column is one of the swig_cast_info structures for that type.
 * The cast_initial array is actually an array of arrays, because each row has
 * a variable number of columns.
 *
 * We loop through the cast[] array associated with the type and mark casts
 * which have not been defined in previously loaded modules by assigning
 * cast pointer value to cast->next. We also hash cast->type->name string
 * and store the value in the cast->value field. If we encounter swig_cast_info
 * structure that represents a cast to self we move it to the beginning
 * of the cast array. One trick we need to do is making sure the type pointer
 * in the swig_cast_info struct is correct.
 *
 * First off, we lookup the cast->type name to see if it is already loaded.
 * There are three cases to handle:
 *  1) If the cast->type has already been loaded AND the type we are adding
 *     casting info to has not been loaded (it is in this module), THEN we
 *     replace the cast->type pointer with the type pointer that has already
 *     been loaded.
 *  2) If BOTH types (the one we are adding casting info to, and the
 *     cast->type) are loaded, THEN the cast info has already been loaded by
 *     the previous module so we just ignore it.
 *  3) Finally, if cast->type has not already been loaded, then we add that
 *     swig_cast_info to the list (because the cast->type) pointer will
 *     be correct.
 *
 * Once the cast array has been set up AND it does have new casts that need
 * to be added we sort non-self cast entries to move filtered out entries
 * to the end of the array and to arrange the rest in the increasing order
 * of their type pointer values. We store the index of the last added entry
 * in the cast->value field of the entry[0] (overwriting the name hash). Then
 * we sort <next|value> fields of the remaining entries to arrange hash values
 * in the increasing order. This way cast->next->type->name field matches
 * the cast->value hash.
 *
 * Example:
 * Array of casts for type stored at 0x5000, cast to type stored at 0x3000
 * has already been loaded
 *
 *      After sweep-and-hash:   After sort-by-type:    After sort-by-hash:
 *        ________________       ________________       ________________
 *       |                |     |                |     |                |
 * Entry |  type = 0x5000 |     |  type = 0x5000 |     |  type = 0x5000 |
 *   0   |                |     |                |     |                |
 *       |  next = Entry0 |     |  next = Entry0 |     |  next = Entry0 |
 *       | value = 1212   |     | value = 3      |     | value = 3      |
 *       |                |     |                |     |                |
 *       |================|     |================|     |================|
 *       |                |     |                |     |                |
 * Entry |  type = 0x2000 |     |  type = 0x1000 |     |  type = 0x1000 |
 *   1   |                |     |                |     |                |
 *       |  next = Entry1 |     |  next = Entry1 |     |  next = Entry3 |
 *       | value = 3434   |     | value = 4545   |     | value = 2323   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x3000 |     |  type = 0x2000 |     |  type = 0x2000 |
 *   2   |                |     |                |     |                |
 *       |  next = 0      |     |  next = Entry2 |     |  next = Entry2 |
 *       | value = 0      |     | value = 3434   |     | value = 3434   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x1000 |     |  type = 0x4000 |     |  type = 0x4000 |
 *   3   |                |     |                |     |                |
 *       |  next = Entry3 |     |  next = Entry3 |     |  next = Entry1 |
 *       | value = 4545   |     | value = 2323   |     | value = 4545   |
 *       |________________|     |________________|     |________________|
 *       |                |     |                |     |                |
 * Entry |  type = 0x4000 |     |  type = 0x3000 |     |  type = 0x3000 |
 *   4   |                |     |                |     |                |
 *       |  next = Entry4 |     |  next = 0      |     |  next = 0      |
 *       | value = 2323   |     | value = 0      |     | value = 0      |
 *       |________________|     |________________|     |________________|
 *
 * Once the cast array has been initialized, we use cast[0]->next field to link
 * it into the list of cast arrays for the type.
 *              ____    ____    ____
 * type->cast->|next|->|next|->|next|->0
 *             |----|  |----|  |----|
 *             |----|  |----|  |----|
 *             |----|  |----|  |----|
 *
 * Subsequent cast resolution works as follows:
 *
 * 1. Check whether the type matches the first entry in the current cast array.
 * 2. If not, then do a binary search over the (0:cast->value] interval using
 *    either type address or the hash value of the type name.
 * 3. If not found, then move over to the next cast array (cast[0]->next).
 *
 * ----------------------------------------------------------------------------- */

#ifdef __cplusplus
extern "C" {
#if 0
} /* c-mode */
#endif
#endif

#if 0
#define SWIGRUNTIME_DEBUG
#endif

#ifndef SWIG_INIT_CLIENT_DATA_TYPE
#define SWIG_INIT_CLIENT_DATA_TYPE void *
#endif

/*
 * Sort function that puts cast entries with nonzero 'next' at the front
 * of the array while ordering them by addresses of their 'type' structs.
 */
SWIGINTERN int SWIG_CastCmpStruct(const void *pa, const void *pb) {
  swig_cast_info *pca = (swig_cast_info *)pa;
  swig_cast_info *pcb = (swig_cast_info *)pb;
  if (pca->type < pcb->type)
  return (pca->next || pcb->next == 0) ? -1 : 1;
  if (pca->type > pcb->type)
  return (pcb->next || pca->next == 0) ? 1 : -1;
  return 0;
}

/*
 * Shell-sort 'next' and 'value' field pairs to order them by 'value'.
 */
SWIGINTERN void SWIG_CastHashSort(swig_cast_info *cast, int size) {
  const int hmax = size/9;
  int h, i;
  for(h = 1; h <= hmax; h = 3*h+1);
  for(; h > 0; h /= 3)
  {
    for(i = h; i < size; ++i)
    {
      swig_cast_info *p = cast[i].next;
      unsigned int hash = cast[i].value;
      int j = i;
      while(j >= h && hash < cast[j-h].value)
      {
        cast[j].next = cast[j-h].next;
        cast[j].value = cast[j-h].value;
        j -= h;
      }
      cast[j].next = p;
      cast[j].value = hash;
    }
  }
}

SWIGRUNTIME void
SWIG_InitializeModule(SWIG_INIT_CLIENT_DATA_TYPE clientdata) {
  size_t i;
  swig_module_info *module_head, *iter;
  int init;
  
  /* check to see if the circular list has been setup, if not, set it up */
  if (swig_module.next==0) {
    /* Initialize the swig_module */
    swig_module.type_initial = swig_type_initial;
    swig_module.cast_initial = swig_cast_initial;
    swig_module.next = &swig_module;
    init = 1;
  } else {
    init = 0;
  }
  
  /* Try and load any already created modules */
  module_head = SWIG_GetModule(clientdata);
  if (!module_head) {
    /* This is the first module loaded for this interpreter */
    /* so set the swig module into the interpreter */
    SWIG_SetModule(clientdata, &swig_module);
  } else {
    /* the interpreter has loaded a SWIG module, but has it loaded this one? */
    iter=module_head;
    do {
      if (iter==&swig_module) {
        /* Our module is already in the list, so there's nothing more to do. */
        return;
      }
      iter=iter->next;
    } while (iter!= module_head);
    
    /* otherwise we must add our module into the list */
    swig_module.next = module_head->next;
    module_head->next = &swig_module;
  }
  
  /* When multiple interpreters are used, a module could have already been initialized in
       a different interpreter, but not yet have a pointer in this interpreter.
       In this case, we do not want to continue adding types... everything should be
       set up already */
  if (init == 0) return;
  
  /* Now work on filling in swig_module.types */
#ifdef SWIGRUNTIME_DEBUG
  printf("SWIG_InitializeModule: size %lu\n", (unsigned long)swig_module.size);
#endif
  for (i = 0; i < swig_module.size; ++i) {
    swig_type_info *type = 0;
    swig_type_info *target_type;
    swig_cast_info *cast, *first;
    int num_mapped = 0;
    
#ifdef SWIGRUNTIME_DEBUG
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
#endif
    
    /* if there is another module already loaded */
    if (swig_module.next != &swig_module) {
      type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, swig_module.type_initial[i]->name);
    }
    if (type) {
      /* Overwrite clientdata field */
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: found type %s\n", type->name);
#endif
      if (swig_module.type_initial[i]->clientdata) {
        type->clientdata = swig_module.type_initial[i]->clientdata;
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: found and overwrite type %s \n", type->name);
#endif
      }
    } else {
      type = swig_module.type_initial[i];
    }
    
    /* Insert casting types */
    cast = first = swig_module.cast_initial[i];
    while (cast->type) {
      /* Don't need to add information already in the list */
      target_type = 0;
#ifdef SWIGRUNTIME_DEBUG
      printf("SWIG_InitializeModule: look cast %s\n", cast->type->name);
#endif
      if (swig_module.next != &swig_module) {
        target_type = SWIG_MangledTypeQueryModule(swig_module.next, &swig_module, cast->type->name);
        if (target_type) {
          /* Target type already defined in another module */
#ifdef SWIGRUNTIME_DEBUG
          printf("SWIG_InitializeModule: found cast %s\n", target_type->name);
#endif
          if (type == swig_module.type_initial[i]) {
#ifdef SWIGRUNTIME_DEBUG
            printf("SWIG_InitializeModule: skip old type %s\n", target_type->name);
#endif
            cast->type = target_type;
            target_type = 0;
          } else {
            /* Check if this cast is already in the list */
            swig_cast_info *ocast = SWIG_TypeCheck(target_type->name, type);
#ifdef SWIGRUNTIME_DEBUG
            if (ocast) printf("SWIG_InitializeModule: skip old cast %s\n", target_type->name);
#endif
            if (!ocast) target_type = 0;
          }
        }
      }
      
      if (!target_type) {
#ifdef SWIGRUNTIME_DEBUG
        printf("SWIG_InitializeModule: adding cast %s\n", cast->type->name);
#endif
        /* Set inclusion mark for sorting */
        cast->next = cast;
        num_mapped++;
        
        if (type == cast->type) {
#ifdef SWIGRUNTIME_DEBUG
          printf("%s : self cast at pos [%li]\n", type->name, cast - first);
#endif
          if (cast - first) {
            /* Move cast to itself to the first entry in the array */
            
            swig_cast_info tmp = *cast;
            *cast = *first;
            *first = tmp;
          }
          first++;
          
        } else {
          cast->value = SWIG_Hash(cast->type->name, (unsigned int)strlen(cast->type->name));
        }
      }
      cast++;
    }
    
    if (num_mapped) {
      if (cast - first) {
        swig_cast_info *tmp;
        
        /* Sort casts by type address for binary search in SWIG_TypeCheckStruct */
        qsort(first, cast - first, sizeof(swig_cast_info), SWIG_CastCmpStruct);
        
        /* Remap back links for added entries */
        cast = swig_module.cast_initial[i] + num_mapped;
        for (tmp = first; tmp < cast; tmp++) {
          tmp->next = tmp;
        }
      }
      
      /* Set the value field of the first entry to the index of the last added entry */
      cast = swig_module.cast_initial[i];
      cast->value = num_mapped - 1;
      
      num_mapped -= (int)(first - cast);
      if (num_mapped > 1) {
        /* Sort <'next','value'> pairs by 'value' for binary search in SWIG_TypeCheck */
        
        SWIG_CastHashSort(first, num_mapped);
      }
      
      first = type->cast;
      if (first) {
        /* Link the current set into the list of cast arrays */
        cast->next = first->next;
        first->next = cast;
      } else {
        cast->next = 0;
        type->cast = cast;
      }
    }
    
    /* Set entry in modules->types array equal to the type */
    swig_module.types[i] = type;
  }
  swig_module.types[i] = 0;
  
#ifdef SWIGRUNTIME_DEBUG
  printf("**** SWIG_InitializeModule: Cast List ******\n");
  for (i = 0; i < swig_module.size; ++i) {
    int j = 0;
    swig_cast_info *cast = swig_module.cast_initial[i];
    printf("SWIG_InitializeModule: type %lu %s\n", (unsigned long)i, swig_module.type_initial[i]->name);
    while (cast->type) {
      printf("SWIG_InitializeModule: cast type %s\n", cast->type->name);
      cast++;
      ++j;
    }
    printf("---- Total casts: %d\n",j);
  }
  printf("**** SWIG_InitializeModule: Cast List ******\n");
#endif
}

/* This function will propagate the clientdata field of type to
* any new swig_type_info structures that have been added into the list
* of equivalent types.  It is like calling
* SWIG_TypeClientData(type, clientdata) a second time.
*/
SWIGRUNTIME void
SWIG_PropagateClientData(void) {
  size_t i;
  static int init_run = 0;
  
  if (init_run) return;
  init_run = 1;
  
  for (i = 0; i < swig_module.size; i++) {
    if (swig_module.types[i]->clientdata) {
      swig_cast_info *head, *cast;
      head = swig_module.types[i]->cast;
      while (head) {
        for (cast = head; (cast - head) <= head->value; cast++) {
          if (!cast->converter) {
            if (cast->type && !cast->type->clientdata)
            SWIG_TypeClientData(cast->type, swig_module.types[i]->clientdata);
          }
        }
        head = head->next;
      }
    }
  }
}

#ifdef __cplusplus
#if 0
{
  /* c-mode */
#endif
}
#endif



#if defined(__cplusplus) && ! defined(XSPROTO)
extern "C"
#endif

XS(SWIG_init) {
  dXSARGS;
  int i;
  (void)items;
  
  SWIG_InitializeModule(0);
  
  /* Install commands */
  for (i = 0; swig_commands[i].name; i++) {
    /* Casts only needed for Perl < 5.10. */
#ifdef __cplusplus
    newXS(const_cast<char*>(swig_commands[i].name), swig_commands[i].wrapper, const_cast<char*>(__FILE__));
#else
    newXS((char*)swig_commands[i].name, swig_commands[i].wrapper, (char*)__FILE__);
#endif
  }
  
  /* Install variables */
  for (i = 0; swig_variables[i].name; i++) {
    SV *sv;
    sv = get_sv(swig_variables[i].name, TRUE | 0x2 | GV_ADDMULTI);
    if (swig_variables[i].type) {
      SWIG_MakePtr(sv,(void *)1, *swig_variables[i].type,0);
    } else {
      sv_setiv(sv,(IV) 0);
    }
    swig_create_magic(sv, swig_variables[i].name, swig_variables[i].set, swig_variables[i].get); 
  }
  
  /* Install constant */
  for (i = 0; swig_constants[i].type; i++) {
    SV *sv;
    sv = get_sv(swig_constants[i].name, TRUE | 0x2 | GV_ADDMULTI);
    switch(swig_constants[i].type) {
    case SWIG_INT:
      sv_setiv(sv, (IV) swig_constants[i].lvalue);
      break;
    case SWIG_FLOAT:
      sv_setnv(sv, (double) swig_constants[i].dvalue);
      break;
    case SWIG_STRING:
      sv_setpv(sv, (const char *) swig_constants[i].pvalue);
      break;
    case SWIG_POINTER:
      SWIG_MakePtr(sv, swig_constants[i].pvalue, *(swig_constants[i].ptype),0);
      break;
    case SWIG_BINARY:
      SWIG_MakePackedObj(sv, swig_constants[i].pvalue, swig_constants[i].lvalue, *(swig_constants[i].ptype));
      break;
    default:
      break;
    }
    SvREADONLY_on(sv);
  }
  
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_int_t, (void*) "Ufal::MorphoDiTa::Indices");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_std__string_t, (void*) "Ufal::MorphoDiTa::Forms");
  SWIG_TypeClientData(SWIGTYPE_p_tagged_form, (void*) "Ufal::MorphoDiTa::TaggedForm");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_tagged_form_t, (void*) "Ufal::MorphoDiTa::TaggedForms");
  SWIG_TypeClientData(SWIGTYPE_p_tagged_lemma, (void*) "Ufal::MorphoDiTa::TaggedLemma");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_tagged_lemma_t, (void*) "Ufal::MorphoDiTa::TaggedLemmas");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_std__vectorT_tagged_lemma_t_t, (void*) "Ufal::MorphoDiTa::Analyses");
  SWIG_TypeClientData(SWIGTYPE_p_tagged_lemma_forms, (void*) "Ufal::MorphoDiTa::TaggedLemmaForms");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_tagged_lemma_forms_t, (void*) "Ufal::MorphoDiTa::TaggedLemmasForms");
  SWIG_TypeClientData(SWIGTYPE_p_token_range, (void*) "Ufal::MorphoDiTa::TokenRange");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_token_range_t, (void*) "Ufal::MorphoDiTa::TokenRanges");
  SWIG_TypeClientData(SWIGTYPE_p_derivated_lemma, (void*) "Ufal::MorphoDiTa::DerivatedLemma");
  SWIG_TypeClientData(SWIGTYPE_p_std__vectorT_derivated_lemma_t, (void*) "Ufal::MorphoDiTa::DerivatedLemmas");
  SWIG_TypeClientData(SWIGTYPE_p_version, (void*) "Ufal::MorphoDiTa::Version");
  SWIG_TypeClientData(SWIGTYPE_p_tokenizer, (void*) "Ufal::MorphoDiTa::Tokenizer");
  SWIG_TypeClientData(SWIGTYPE_p_derivator, (void*) "Ufal::MorphoDiTa::Derivator");
  /*@SWIG:/home/fox/bin.local/swig-build/share/swig/4.4.0/perl5/perltypemaps.swg,67,%set_constant@*/ do {
    SV *sv = get_sv((char*) SWIG_prefix "Morpho_NO_GUESSER", TRUE | 0x2 | GV_ADDMULTI);
    sv_setsv(sv, SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(morpho::NO_GUESSER)));
    SvREADONLY_on(sv);
  } while(0) /*@SWIG@*/;
  /*@SWIG:/home/fox/bin.local/swig-build/share/swig/4.4.0/perl5/perltypemaps.swg,67,%set_constant@*/ do {
    SV *sv = get_sv((char*) SWIG_prefix "Morpho_GUESSER", TRUE | 0x2 | GV_ADDMULTI);
    sv_setsv(sv, SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(morpho::GUESSER)));
    SvREADONLY_on(sv);
  } while(0) /*@SWIG@*/;
  /*@SWIG:/home/fox/bin.local/swig-build/share/swig/4.4.0/perl5/perltypemaps.swg,67,%set_constant@*/ do {
    SV *sv = get_sv((char*) SWIG_prefix "Morpho_GUESSER_UNSPECIFIED", TRUE | 0x2 | GV_ADDMULTI);
    sv_setsv(sv, SWIG_From_int  SWIG_PERL_CALL_ARGS_1(static_cast< int >(morpho::GUESSER_UNSPECIFIED)));
    SvREADONLY_on(sv);
  } while(0) /*@SWIG@*/;
  SWIG_TypeClientData(SWIGTYPE_p_morpho, (void*) "Ufal::MorphoDiTa::Morpho");
  SWIG_TypeClientData(SWIGTYPE_p_tagger, (void*) "Ufal::MorphoDiTa::Tagger");
  SWIG_TypeClientData(SWIGTYPE_p_tagset_converter, (void*) "Ufal::MorphoDiTa::TagsetConverter");
  SWIG_TypeClientData(SWIGTYPE_p_derivation_formatter, (void*) "Ufal::MorphoDiTa::DerivationFormatter");
  ST(0) = &PL_sv_yes;
  XSRETURN(1);
}

